megabus_control = {}

-- Front driver, dual pass mosfet
function drive_f_2(n, x, y, dy, o)
   local nl = match(n, [[
N12=t(o, n8, c)
N0=t(n18, n5, o)
N24=gnd(n18)
N18=t(n8, n33, i1)
N38=vcc(n33)
N17=t(n5, n32, i2)
N37=vcc(n32)
]], {o=o})
   move(nl, x, y, [[
N12 -10 7 no,
N0 -13 2 en18,
N24 -14 -2,
N18 6 12 nn8,
N38 6 16,
N17 6 3 nn5,
N37 6 7,
]])
   route(nl, x, y+dy, [[
i1 10 4,
i2 10 2,
]])
   return nl
end

-- Front driver, dual pass mosfet, inverted
function drive_f_2i(n, x, y, dy, o)
   local nl = match(n, [[
N12=t(o, n8, c)
N0=t(n18, n5, o)
N24=gnd(n18)
N18=t(n8, n33, i2)
N38=vcc(n33)
N17=t(n5, n32, i1)
N37=vcc(n32)
]], {o=o})
   move(nl, x, y, [[
N12 -10 7 no,
N0 -13 2 en18,
N24 -14 -2,
N18 6 12 nn8,
N38 6 16,
N17 6 3 nn5,
N37 6 7,
]])
   nl.i1:route(x+12, y+2)
   route(nl, x, y+dy, [[
i1 12 4,
i2 10 2,
]])
   return nl
end

-- Front driver, single pass mosfet, inverted
function drive_f_1i(n, x, y, dy, o)
   local nl = match(n, [[
N12=t(o, n8, c)
N0=t(n18, i1, o)
N24=gnd(n18)
N18=t(n8, n33, i2)
N38=vcc(n33)
]], {o=o})
   move(nl, x, y, [[
N12 -10 7 no,
N0 -13 2 en18,
N24 -14 -2,
N18 6 12 nn8,
N38 6 16,
]])
   nl.i1:route(x+12, y+2)
   route(nl, x, y+dy, [[
i1 12 4,
i2 10 2,
]])
   return nl
end

-- Back driver, simple inverter, enh pullup
function drive_b_e(n, x, y, o1, o2)
   local nl = match(n, [[
N9=t(n27, n27, o2)
N32=vcc(n27)
N3=t(o2, i, n21)
N27=gnd(n21)
]], {i=o1, o2=o2})
   move(nl, x, y, [[
N9 4 2 eo2,
N32 3 6,
N3 4 -6 en21,
N27 3 -10,
]])
   route(nl, x, y, [[
i 0 0 0 9 10 9 10 1 10 -1 10 -6,
]])
   return nl
end

-- Back driver, simple inverter, dpl pullup
function drive_b_d(n, x, y, o1, o2)
   local nl = match(n, [[
N9=d(n27, o2, o2)
N32=vcc(n27)
N3=t(o2, i, n21)
N27=gnd(n21)
]], {i=o1, o2=o2})
   move(nl, x, y, [[
N9 4 2 eo2,
N32 3 6,
N3 4 -6 en21,
N27 3 -10,
]])
   route(nl, x, y, [[
i 0 0 0 9 10 9 10 1 10 -1 10 -6,
]])
   return nl
end

-- Back driver, doubled inverter, dpl pullup
function drive_b_d2(n, x, y, o1, o2)
   local nl = match(n, [[
N9=d(n27, o2, o2)
N32=vcc(n27)
N4=t(o2, n2, n21)
N27=gnd(n21)
N0=d(n1, n2, n2)
N1=vcc(n1)
N2=t(n2, i, n3)
N3=gnd(n3)
]], {n2=o1, o2=o2})
   move(nl, x, y, [[
N9 4 2 eo2,
N32 3 6,
N4 4 -6 en21,
N27 3 -10,
N0 14 2 en2,
N1 13 6,
N2 14 -6 en3,
N3 13 -10,
]])
   route(nl, x, y, [[
n2 0 0 0 9 10 9 10 -2 10 -6,
]])
   return nl
end

function drive_0_2e(n, x, y, o)
   local nl = drive_f_2(n, x, y, 5, o)
   local nl2 = drive_b_e(n, x+46, y+9, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_2e(n, x, y, o)
   local nl = drive_f_2(n, x+26, y-12, 3, o)
   local nl2 = drive_b_e(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_0_2ie(n, x, y, o)
   local nl = drive_f_2i(n, x, y, 5, o)
   local nl2 = drive_b_e(n, x+46, y+9, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_2ie(n, x, y, o)
   local nl = drive_f_2i(n, x+26, y-12, 3, o)
   local nl2 = drive_b_e(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_0_2d(n, x, y, o)
   local nl = drive_f_2(n, x, y, 5, o)
   local nl2 = drive_b_d(n, x+46, y+9, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_2d(n, x, y, o)
   local nl = drive_f_2(n, x+26, y-12, 3, o)
   local nl2 = drive_b_d(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_0_1id(n, x, y, o)
   local nl = drive_f_1i(n, x, y, 5, o)
   local nl2 = drive_b_d(n, x+46, y+9, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_1id(n, x, y, o)
   local nl = drive_f_1i(n, x+26, y-12, 3, o)
   local nl2 = drive_b_d(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_0_2id(n, x, y, o)
   local nl = drive_f_2i(n, x, y, 5, o)
   local nl2 = drive_b_d(n, x+46, y+9, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_2id(n, x, y, o)
   local nl = drive_f_2i(n, x+26, y-12, 3, o)
   local nl2 = drive_b_d(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_2id2(n, x, y, o)
   local nl = drive_f_2i(n, x+26, y-12, 3, o)
   local nl2 = drive_b_d2(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_1_1id2(n, x, y, o)
   local nl = drive_f_1i(n, x+26, y-12, 3, o)
   local nl2 = drive_b_d2(n, x+61, y-5, nl.i1, nl.i2)
   return nl2.i, nl.c
end

function drive_latched(n, x, y, o)
   local nl = match(n, "A=t(v,nr,o) B=t(o,r,g) V=vcc(v) G=gnd(g)", { o=o })
   move(nl, x, y, "A 1 14 eo, B 1 6 eg, V 0 18, G 0 2")
   route(nl, x, y, "nr 5 10, r 5 -1 13 -1")
   nl = latchi(n, x+25, y, { nr=nl.nr })
   return nl.ri
end

function drive_i_latched(n, x, y, o)
   local nl = match(n, "A=t(v,r,o) B=t(o,nr,g) V=vcc(v) G=gnd(g)", { o=o })
   move(nl, x, y, "A 1 14 eo, B 1 6 eg, V 0 18, G 0 2")
   route(nl, x, y, "nr 5 10, r 5 21 18 21")
   nl = latchi(n, x+25, y, { nr=nl.nr })
   return nl.ri
end

function feedback(n, x, y, i)
   local nl = match(n, [[
A=t(e, c, b)
B=t(f, a, c)
C=t(g, c, d)
D=t(b, d, h)
E=d(c, c, i)
F=d(d, d, j)
G=gnd(e)
H=gnd(f)
I=gnd(g)
J=vcc(h)
K=vcc(i)
L=vcc(j)
]], { a = i })
   move(nl, x, y, [[
E  0 12 wc,
K  1 16,
B  0  4 wf,
H  1  0,
F  8 12 ed,
L  7 16,
C  8  4 eg,
I  7  0,
D 16 12 wb,
J 17 16,
A 16  4 we,
G 17  0,
]])
   route(nl, x, y, [[
c 4 8 4 -3 12 -3,
]])
   return nl.b
end

function ifeedback(n, x, y, i)
   local nl = match(n, [[
A=t(e, c, b)
C=t(g, c, d)
D=t(b, d, h)
F=d(d, d, j)
G=gnd(e)
I=gnd(g)
J=vcc(h)
L=vcc(j)
]], { c = i })
   move(nl, x, y, [[
F  1 12 ed,
L  0 16,
C  1  4 eg,
I  0  0,
D  9 12 wb,
J 10 16,
A  9  4 we,
G 10  0,
]])
   route(nl, x, y, [[
]])
   return nl.b
end

function rw_driver(n, x, y, dx, o)
   local nl = match(n, [[
A=t(d, f, k)
B=t(i, f, l)
C=t(m, g, j)
D=d(n, d, d)
E=d(j, j, o)
F=t(c, h, a)
G=t(b, e, c)
H=t(c, g, i)
I=t(d, p, e)
J=t(h, q, j)
K=gnd(k)
L=gnd(l)
M=gnd(m)
N=vcc(n)
O=vcc(o)
P=vcc(p)
Q=vcc(q)
R=t(f, r, s)
S=t(g, r, t)
]], { c = o })

   move(nl, x, y, [[
G  32   7 ec,
I  40   8 ne,
P  40  12,
D  48   7 wd,
N  49  11,
A  54   7 ek,
K  53   3,

F  32  -7 ea,
J  40  -6 nh,
Q  40  -2,
E  48  -7 wj,
O  49  -3,
C  54  -7 em,
M  53 -11,

H  58  -1 sc,
B  66   1 ni,
L  70   0,
]])

   move(nl, x+dx, y, [[
R 115   6 sf,
S 115  -6 ng,
]])

   route(nl, x, y, [[
c 31 0,
d 51 3 51 11,
j 51 -3 51 -11,
f 66 7,
]])

   route(nl, x+dx, y, [[
r 111 -2 111 2,
]])

   return nl
end


function simple_driver_inverted(n, x, y, c)
   local nl = match(n, "A=t(d, i, o) B=t(c, i, e) C=t(o, c, f) D=d(c, c, g) E=gnd(d) F=gnd(e) G=vcc(f) H=vcc(g)", c)
   move(nl, x, y, "C -4 4 sf, G -8 5, A 4 4 so, E 8 5, D -4 -4 ng, H -8 -5, B 4 -4 nc, F 8 -5")
   route(nl, x, y, "o 0 7")
   return nl
end

local n = nodes_rect(1655, 4130, 1756, 3610)
for y=0,17 do
   local yy = 4106-27*y
   megabus_control[string.format("r%dh_dbc", y)] = drive_0_2e(n, 1670, yy, megabus[string.format("r%dh_dbc", y)])
   megabus_control[string.format("r%dh_abc", y)] = drive_1_2e(n, 1670, yy, megabus[string.format("r%dh_abc", y)])
end


n = nodes_rect(1655, 2500, 1756, 2190)
for y=1,9 do
   local yy = 2461-27*y
   megabus_control[string.format("r%dl_dbc", y)] = drive_0_2e(n, 1670, yy, megabus[string.format("r%dl_dbc", y)])
   megabus_control[string.format("r%dl_abc", y)] = drive_1_2e(n, 1670, yy, megabus[string.format("r%dl_abc", y)])
end

n = nodes_rect(1655, 1970, 1756, 1700)
for y=0,8 do
   local yy = 1940-27*y
   megabus_control[string.format("r%dd_dbc", y)] = drive_0_2e(n, 1670, yy, megabus[string.format("r%dd_dbc", y)])
   megabus_control[string.format("r%dd_abc", y)] = drive_1_2e(n, 1670, yy, megabus[string.format("r%dd_abc", y)])
end

megabus_control.r8d_dbc:route(2007, 2564, 1888, 2564, 1888, 1732)
megabus_control.r8d_abc:route(2047, 2566, 1886, 2566, 1886, 1718)

n = nodes_rect(1655, 3632, 1756, 3465)
megabus_control.aobh_r = drive_0_1id(n, 1670, 3612, megabus.aobh_r)
megabus_control.aobh_a_w = drive_1_2e(n, 1670, 3612, megabus.aobh_a_w)
megabus_control.aobh_d_w = drive_0_2e(n, 1670, 3583, megabus.aobh_d_w)
megabus_control.aobh_auh_w = drive_1_2e(n, 1670, 3583, megabus.aobh_auh_w)
megabus_control.pch_dbc = drive_0_2id(n, 1670, 3554, megabus.pch_dbc)
megabus_control.pch_abc = drive_1_2id(n, 1670, 3554, megabus.pch_abc)
megabus_control.pch_auh_w = drive_0_2e(n, 1670, 3527, megabus.pch_auh_w)
megabus_control.auh_d_w = drive_1_2e(n, 1670, 3527, megabus.auh_d_w)
megabus_control.auh_a_w = drive_0_2e(n, 1670, 3500, megabus.auh_a_w)
megabus_control.auh_aluh_w = drive_1_2id2(n, 1670, 3500, megabus.auh_aluh_w)

megabus.hd_active:route(1645, 3330, 1645, 3331)
megabus.ha_active:route(1643, 3332, 1643, 3341)
megabus.aluh_ab_in:route(1633, 3340, 1633, 3386)
megabus.aluh_cst_in:route(1635, 3338, 1635, 3366)
megabus.aluh_cst_val:route(1637, 3336, 1637, 3356)
megabus.aobh_r:route(1630, 3618, 1630, 3633)
megabus.aobh_a_w:route(1630, 3606, 1630, 3594)
megabus.aobh_d_w:route(1630, 3589, 1630, 3592)
megabus.aobh_auh_w:route(1630, 3577, 1630, 3568)
megabus.pch_auh_w:route(1630, 3533, 1630, 3540)
megabus.auh_d_w:route(1628, 3521, 1628, 3497)
megabus.auh_a_w:route(1630, 3506, 1630, 3485)
megabus.auh_aluh_w:route(1632, 3494, 1632, 3483)
megabus_control.r17h_dbc:route(1753, 3655, 1753, 3620, 1897, 3620, 1897, 4107, 2047, 4107)
megabus_control.r17h_abc:route(1751, 3641, 1751, 3618, 1899, 3618, 1899, 4109, 1997, 4109)

n = nodes_rect(1762, 3501, 1770, 3495)
nl = match(n, "A=t(o, t, i)", { o = megabus_control.auh_aluh_w })
nl.A:move(1785, 3488, "s", nl.o)
nl.t:route(1781, 3484)

n = nodes_rect(1750, 4130, 1930, 3640)
nl = match(n, [[
N0=t(r0h_abc, n10, n70)
N1=t(n10, n10, n71)
N2=t(n72, n10, r0h_dbc)
N3=t(r1h_dbc, n10, n73)
N4=t(r1h_abc, n10, n74)
N5=t(r2h_abc, n10, n75)
N6=t(n76, n22, n22)
N7=t(n77, n10, r2h_dbc)
N8=t(r3h_abc, n10, n78)
N9=t(r3h_dbc, n10, n79)
N10=t(r4h_abc, n10, n80)
N11=t(n81, n10, r4h_dbc)
N12=t(r5h_abc, n10, n82)
N13=t(r5h_dbc, n10, n83)
N14=t(r6h_abc, n10, n84)
N15=t(n85, n10, r6h_dbc)
N16=t(r7h_abc, n10, n86)
N17=t(r7h_dbc, n10, n87)
N18=t(r8h_abc, n10, n88)
N19=t(n89, n10, r8h_dbc)
N20=t(r9h_abc, n10, n90)
N21=t(r9h_dbc, n10, n91)
N22=t(r10h_abc, n10, n92)
N23=t(n93, n10, r10h_dbc)
N24=t(r11h_abc, n10, n94)
N25=t(r11h_dbc, n10, n95)
N26=t(r12h_abc, n10, n96)
N27=t(n97, n10, r12h_dbc)
N28=t(r13h_abc, n10, n98)
N29=t(r13h_dbc, n10, n99)
N30=t(r14h_abc, n10, n100)
N31=t(n101, n10, r14h_dbc)
N32=t(r15h_dbc, n10, n102)
N33=t(r15h_abc, n10, n103)
N34=t(n104, n10, r16h_abc)
N35=t(r16h_dbc, n10, n105)
N36=t(n106, n12, n15)
N37=t(n107, n5, n19)
N38=t(n22, n108, n108)
N39=t(n109, n12, n3)
N40=t(n110, n5, n28)
N41=t(n111, n12, n33)
N42=t(n112, n5, n36)
N43=t(n39, n12, n113)
N44=t(n114, n5, n42)
N45=t(n46, n1, n115)
N46=t(n116, n4, n47)
N47=t(n52, n1, n117)
N48=t(n53, n4, n118)
N49=t(n58, n1, n119)
N50=t(n120, n4, n60)
N51=t(n121, n1, n67)
N52=t(n122, n4, n68)
N53=t(n6, n7, r0h_abc)
N54=t(n6, n11, n14)
N55=t(n6, n18, r1h_abc)
N56=t(n8, n16, n17)
N57=t(n8, n13, n19)
N58=t(n10, n22, n22)
N59=t(n14, n9, n15)
N60=t(n17, n20, r0h_dbc)
N61=t(r1h_dbc, n21, n17)
N62=t(r2h_abc, n7, n24)
N63=t(n23, n20, r2h_dbc)
N64=t(r3h_dbc, n21, n23)
N65=t(n26, n27, n23)
N66=t(n24, n0, n2)
N67=t(n24, n18, r3h_abc)
N68=t(n2, n9, n3)
N69=t(n26, n13, n28)
N70=t(r4h_abc, n7, n31)
N71=t(n29, n20, r4h_dbc)
N72=t(r5h_dbc, n21, n29)
N73=t(n34, n16, n29)
N74=t(n31, n18, r5h_abc)
N75=t(n31, n11, n32)
N76=t(n32, n30, n33)
N77=t(n34, n35, n36)
N78=t(r6h_abc, n7, n38)
N79=t(n37, n20, r6h_dbc)
N80=t(r7h_dbc, n21, n37)
N81=t(n41, n27, n37)
N82=t(n38, n0, n40)
N83=t(n38, n18, r7h_abc)
N84=t(n39, n30, n40)
N85=t(n41, n35, n42)
N86=t(r8h_abc, n7, n44)
N87=t(n43, n20, r8h_dbc)
N88=t(r9h_dbc, n21, n43)
N89=t(n43, n16, n48)
N90=t(n44, n18, r9h_abc)
N91=t(n44, n11, n45)
N92=t(n45, n9, n46)
N93=t(n47, n13, n48)
N94=t(r10h_abc, n7, n50)
N95=t(n49, n20, r10h_dbc)
N96=t(r11h_dbc, n21, n49)
N97=t(n49, n27, n54)
N98=t(n50, n0, n51)
N99=t(n50, n18, r11h_abc)
N100=t(n51, n9, n52)
N101=t(n53, n13, n54)
N102=t(r12h_abc, n7, n56)
N103=t(n55, n20, r12h_dbc)
N104=t(r13h_dbc, n21, n55)
N105=t(n59, n16, n55)
N106=t(n56, n11, n57)
N107=t(n56, n18, r13h_abc)
N108=t(n57, n30, n58)
N109=t(n59, n35, n60)
N110=t(r14h_abc, n7, n62)
N111=t(n61, n20, r14h_dbc)
N112=t(n61, n27, n64)
N113=t(n61, n21, n65)
N114=t(n62, n0, n66)
N115=t(n62, n18, n69)
N116=t(r15h_dbc, n63, n65)
N117=t(n64, n35, n68)
N118=t(n65, n25, r16h_dbc)
N119=t(n66, n30, n67)
N120=t(n69, n63, r15h_abc)
N121=t(r16h_abc, n25, n69)
N122=gnd(n70)
N123=gnd(n71)
N124=gnd(n72)
N125=gnd(n73)
N126=gnd(n74)
N127=gnd(n75)
N128=gnd(n76)
N129=gnd(n77)
N130=gnd(n78)
N131=gnd(n79)
N132=gnd(n80)
N133=gnd(n81)
N134=gnd(n82)
N135=gnd(n83)
N136=gnd(n84)
N137=gnd(n85)
N138=gnd(n86)
N139=gnd(n87)
N140=gnd(n88)
N141=gnd(n89)
N142=gnd(n90)
N143=gnd(n91)
N144=gnd(n92)
N145=gnd(n93)
N146=gnd(n94)
N147=gnd(n95)
N148=gnd(n96)
N149=gnd(n97)
N150=gnd(n98)
N151=gnd(n99)
N152=gnd(n100)
N153=gnd(n101)
N154=gnd(n102)
N155=gnd(n103)
N156=gnd(n104)
N157=gnd(n105)
N158=vcc(n106)
N159=vcc(n107)
N160=vcc(n108)
N161=vcc(n109)
N162=vcc(n110)
N163=vcc(n111)
N164=vcc(n112)
N165=vcc(n113)
N166=vcc(n114)
N167=vcc(n115)
N168=vcc(n116)
N169=vcc(n117)
N170=vcc(n118)
N171=vcc(n119)
N172=vcc(n120)
N173=vcc(n121)
N174=vcc(n122)

]], megabus_control)

move(nl, 0, 0, [[
N60 1825 4110 wn17,
N53 1839 4096 wn6,
N61 1832 4083 wn17,
N55 1846 4069 wn6,
N63 1825 4056 wn23,
N62 1839 4042 wn24,
N64 1832 4029 wn23,
N67 1846 4015 wn24,
N71 1825 4002 wn29,
N70 1839 3988 wn31,
N72 1832 3975 wn29,
N74 1846 3961 wn31,
N79 1825 3948 wn37,
N78 1839 3934 wn38,
N80 1832 3921 wn37,
N83 1846 3907 wn38,
N87 1825 3894 wn43,
N86 1839 3880 wn44,
N88 1832 3867 wn43,
N90 1846 3853 wn44,
N95 1825 3840 wn49,
N94 1839 3826 wn50,
N96 1832 3813 wn49,
N99 1846 3799 wn50,
N103 1825 3786 wn55,
N102 1839 3772 wn56,
N104 1832 3759 wn55,
N107 1846 3745 wn56,
N111 1825 3732 wn61,
N110 1839 3718 wn62,

N1 1855 4123 wn71,
N123 1856 4119,
N58 1855 4131 wn10,
N6 1860 4135 wn76,
N128 1861 4131,
N38 1860 4143 wn22,
N160 1861 4147,

N2 1855 4110 wn72,
N124 1856 4106,
N0 1855 4096 wn70,
N122 1856 4092,
N3 1855 4083 wn73,
N125 1856 4079,
N4 1855 4069 wn74,
N126 1856 4065,
N7 1855 4056 wn77,
N129 1856 4052,
N5 1855 4042 wn75,
N127 1856 4038,
N9 1855 4029 wn79,
N131 1856 4025,
N8 1855 4015 wn78,
N130 1856 4011,
N11 1855 4002 wn81,
N133 1856 3998,
N10 1855 3988 wn80,
N132 1856 3984,
N13 1855 3975 wn83,
N135 1856 3971,
N12 1855 3961 wn82,
N134 1856 3957,
N15 1855 3948 wn85,
N137 1856 3944,
N14 1855 3934 wn84,
N136 1856 3930,
N17 1855 3921 wn87,
N139 1856 3917,
N16 1855 3907 wn86,
N138 1856 3903,
N19 1855 3894 wn89,
N141 1856 3890,
N18 1855 3880 wn88,
N140 1856 3876,
N21 1855 3867 wn91,
N143 1856 3863,
N20 1855 3853 wn90,
N142 1856 3849,
N23 1855 3840 wn93,
N145 1856 3836,
N22 1855 3826 wn92,
N144 1856 3822,
N25 1855 3813 wn95,
N147 1856 3809,
N24 1855 3799 wn94,
N146 1856 3795,
N27 1855 3786 wn97,
N149 1856 3782,
N26 1855 3772 wn96,
N148 1856 3768,
N29 1855 3759 wn99,
N151 1856 3755,
N28 1855 3745 wn98,
N150 1856 3741,
N31 1855 3732 wn101,
N153 1856 3728,
N30 1855 3718 wn100,
N152 1856 3714,
N32 1855 3705 wn102,
N154 1856 3701,
N33 1855 3691 wn103,
N155 1856 3687,
N35 1855 3678 wn105,
N157 1856 3674,
N34 1855 3664 wn104,
N156 1856 3660,

N159 1751 4109,
N37 1755 4108 sn107,
N57 1777 4108 sn19,
N56 1799 4108 sn8,

N158 1751 4095,
N36 1755 4094 sn106,
N59 1777 4094 sn15,
N54 1799 4094 sn14,

N162 1751 4055,
N40 1755 4054 sn110,
N69 1777 4054 sn28,
N65 1810 4054 sn26,

N161 1751 4041,
N39 1755 4040 sn109,
N68 1777 4040 sn3,
N66 1810 4040 sn2,

N164 1751 4001,
N42 1755 4000 sn112,
N77 1788 4000 sn36,
N73 1799 4000 sn34,

N163 1751 3987,
N41 1755 3986 sn111,
N76 1788 3986 sn33,
N75 1799 3986 sn32,

N166 1751 3947,
N44 1755 3946 sn114,
N85 1788 3946 sn42,
N81 1810 3946 sn41,

N165 1751 3933,
N43 1755 3932 sn113,
N84 1788 3932 sn39,
N82 1810 3932 sn40,

N168 1762 3893,
N46 1766 3892 sn116,
N93 1777 3892 sn47,
N89 1799 3892 sn48,

N167 1762 3879,
N45 1766 3878 sn115,
N92 1777 3878 sn46,
N91 1799 3878 sn45,

N170 1762 3839,
N48 1766 3838 sn118,
N101 1777 3838 sn53,
N97 1810 3838 sn54,

N169 1762 3825,
N47 1766 3824 sn117,
N100 1777 3824 sn52,
N98 1810 3824 sn51,

N172 1762 3785,
N50 1766 3784 sn120,
N109 1788 3784 sn60,
N105 1799 3784 sn59, 

N171 1762 3771,
N49 1766 3770 sn119,
N108 1788 3770 sn58,
N106 1799 3770 sn57,

N174 1762 3731,
N52 1766 3730 sn122,
N117 1788 3730 sn68,
N112 1810 3730 sn64,

N173 1762 3717,
N51 1766 3716 sn121,
N119 1788 3716 sn67,
N114 1810 3716 sn66,

N116 1753 3705 en65,
N120 1753 3691 en69,
N118 1751 3678 en65,
N121 1751 3664 en69,
N113 1776 3702 nn65,
N115 1776 3688 nn69,
]])

route(nl, 0, 0, [[
n17 1819 4109 1819 4106 1826 4079,
n6  1833 4095 1833 4092 1840 4065,
n23 1819 4055 1819 4052 1826 4025,
n24 1833 4041 1833 4038 1840 4011,
n29 1819 4001 1819 3998 1826 3971,
n31 1833 3987 1833 3984 1840 3957,
n37 1819 3947 1819 3944 1826 3917,
n38 1833 3933 1833 3930 1840 3903,
n43 1819 3893 1819 3890 1826 3863,
n44 1833 3879 1833 3876 1840 3849,
n49 1819 3839 1819 3836 1826 3809,
n50 1833 3825 1833 3822 1840 3795,
n55 1819 3785 1819 3782 1826 3755,
n56 1833 3771 1833 3768 1840 3741,
n61 1819 3731 1819 3728 1826 3701,
n62 1833 3717 1833 3714 1840 3687,

n5  1759 4104 1759 4077 1759 4050 1759 4023 1759 3996 1759 3969 1759 3942,
n4  1770 3888 1770 3861 1770 3834 1770 3807 1770 3780 1770 3753 1770 3726,
n12 1761 4090 1761 4063 1761 4036 1761 4009 1761 3982 1761 3955 1761 3928,
n1  1772 3874 1772 3847 1772 3820 1772 3793 1772 3766 1772 3739 1772 3712,

n13 1781 4104 1781 4077 1781 4050 1781 4023 1781 3888 1781 3861 1781 3834,
n35 1792 3996 1792 3969 1792 3942 1792 3915 1792 3780 1792 3753 1792 3726,
n9  1783 4090 1783 4063 1783 4036 1783 4009 1783 3874 1783 3847 1783 3820,
n30 1794 3982 1794 3955 1794 3928 1794 3901 1794 3766 1794 3739 1794 3712,

n16 1803 4104 1803 4077 1803 3996 1803 3969 1803 3888 1803 3861 1803 3780,
n27 1814 4050 1814 4023 1814 3942 1814 3915 1814 3834 1814 3807 1814 3726,
n11 1805 4090 1805 4063 1805 3982 1805 3955 1805 3874 1805 3847 1805 3766,
n0  1816 4036 1816 4009 1816 3928 1816 3901 1816 3820 1816 3793 1816 3712,

n21 1828 3706, 
n18 1842 3692,
n65 1766 3701 1766 3674,
n69 1768 3687 1768 3660,

n21 2012 3979 2012 4015,
n20 2014 3977 2014 3994,
n27 2012 3879 2012 3915,
n16 2014 3877 2014 3894,
n35 2012 3929 2012 3965,
n13 2014 3927 2014 3944,
n4  2045 4029 2045 4079,
n5  2047 4027,
]])

nl.n10:set_name("pd1a")
nl.n22:set_name("pd1b")

local function xroute(n, x1, x2, y0, y1, y2)
   for y = y0,y1,20 do
      n:route(x1, y)
   end
   for y = y0,y2,20 do
      n:route(x2, y)
   end
   n:route(x1, y1)
   n:route(1853, y0)
   n:route(x2, y2)
end

xroute(nl.n18, 1842, 1865, 3656, 4069, 4015)
xroute(nl.n7,  1835, 1867, 3654, 4096, 3994)
xroute(nl.n21, 1828, 1869, 3652, 4083, 3979)
xroute(nl.n20, 1821, 1871, 3650, 4110, 3977)
xroute(nl.n0,  1816, 1873, 3648, 4036, 3915)
xroute(nl.n27, 1814, 1875, 3646, 4050, 3879)
xroute(nl.n11, 1805, 1877, 3644, 4090, 3894)
xroute(nl.n16, 1803, 1879, 3642, 4104, 3877)
xroute(nl.n30, 1794, 1881, 3640, 3982, 3965)
xroute(nl.n35, 1792, 1883, 3638, 3996, 3929)
xroute(nl.n9,  1783, 1885, 3636, 4090, 3944)
xroute(nl.n13, 1781, 1887, 3634, 4104, 3927)
xroute(nl.n1,  1772, 1889, 3632, 3874, 4079)
xroute(nl.n4,  1770, 1891, 3630, 3888, 4029)
xroute(nl.n12, 1761, 1893, 3628, 4090, 4044)
xroute(nl.n5,  1759, 1895, 3626, 4104, 4027)

megabus_control.rhsel_raba = nl.n18
megabus_control.rhsel_rdba = nl.n7
megabus_control.rhsel_rabd = nl.n21
megabus_control.rhsel_rdbd = nl.n20
megabus_control.rhsel_01ba = nl.n0
megabus_control.rhsel_01bd = nl.n27
megabus_control.rhsel_00ba = nl.n11
megabus_control.rhsel_00bd = nl.n16
megabus_control.rhsel_11ba = nl.n30
megabus_control.rhsel_11bd = nl.n35
megabus_control.rhsel_10ba = nl.n9
megabus_control.rhsel_10bd = nl.n13
megabus_control.rhsel_21ba = nl.n1
megabus_control.rhsel_21bd = nl.n4
megabus_control.rhsel_20ba = nl.n12
megabus_control.rhsel_20bd = nl.n5


local function regsel_dual_driver(n, x, y, o0, o1)
   local nl = match(n, [[
N97=t(n164, n66, o1)
N241=vcc(n164)
N52=t(o1, n65, n118)
N195=gnd(n118)

N105=d(n172, n66, n66)
N249=vcc(n172)
N59=t(n126, n65, n66)
N203=gnd(n126)

N21=t(o0, i, n88)
N216=vcc(n139)
N72=t(n139, n65, o0)
N165=gnd(n88)

N104=d(n171, n65, n65)
N248=vcc(n171)
N58=t(n125, i, n65)
N202=gnd(n125)
]], {o0=o0, o1=o1})

   move(nl, x, y, [[
N97 0 29 eo1,
N241 -1 33,
N52 0 21 en118,
N195 -1 17,

N105 8 29 wn66,
N249 9 33,
N59 8 21 wn126,
N203 9 17,

N72 0 8 eo0,
N216 -1 12,
N21 0 0 en88,
N165 -1 -4,

N104 8 8 wn65,
N248 9 12,
N58 8 0 wn125,
N202 9 -4,
]])
   return nl
end

local function regsel_dual_driver_t(n, x, y, o0, o1)
   local nl = match(n, [[
N45=t(o0, n33, n95)
N148=vcc(n95)
N14=t(n62, t, o0)
N118=gnd(n62)
N15=t(n63, i, o0)
N119=gnd(n63)

N63=d(n33, n33, n110)
N163=vcc(n110)
N35=t(n84, t, n33)
N138=gnd(n84)
N36=t(n85, i, n33)
N139=gnd(n85)

N61=t(n108, n3, o1)
N161=vcc(n108)
N32=t(n81, t, o1)
N135=gnd(n81)
N33=t(o1, n5, n82)
N136=gnd(n82)

N55=d(n3, n3, n104)
N157=vcc(n104)
N29=t(n78, t, n3)
N132=gnd(n78)
N30=t(n3, n5, n79)
N133=gnd(n79)

N62=d(n5, n5, n109)
N162=vcc(n109)
N34=t(n83, i, n5)
N137=gnd(n83)
]], { o0=o0, o1=o1 })

   move(nl, x, y, [[
N45 0 19 eo0,
N148 -1 23,
N14 0 11 en62,
N118 -1 7,
N15 0 0 en63,
N119 -1 -4,

N63 10 19 wn33,
N163 11 23,
N35 10 11 wn84,
N138 11 7,
N36 10 0 wn85,
N139 11 -4,

N61 0 54 eo1,
N161 -1 58,
N32 0 46 en81,
N135 -1 43,
N33 0 35 en82,
N136 -1 31,

N55 10 54 wn3,
N157 11 58,
N29 10 46 wn78,
N132 11 43,
N30 10 35 wn79,
N133 11 31,

N62 16 13 en5,
N162 15 17,
N34 16 5 en83,
N137 15 1,
]])

   route(nl, x, y, [[
o0 -3 4 -3 15,
n33 13 4 13 15,
i 6 -7 20 -7,
n5 6 26 20 26,
t 4 28 20 28,
o1 -3 39 -3 50,
n3 13 39 13 50,
]])
   return nl
end

local function regsel_single_driver_it(n, x, y, o)
   local nl = match(n, [[
N31=t(o, n20, n71)
N116=vcc(n71)
N11=t(n52, t, o)
N99=gnd(n52)
N12=t(o, n23, n53)
N100=gnd(n53)

N28=d(n20, n20, n70)
N115=vcc(n70)
N9=t(n20, t, n50)
N96=gnd(n50)
N10=t(n51, n23, n20)
N98=gnd(n51)

N37=d(n23, n23, n72)
N117=vcc(n72)
N13=t(n54, i, n23)
N101=gnd(n54)
]], {o=o})

   move(nl, x, y, [[
N31 0 19 eo,
N116 -1 23,
N11 0 11 en52,
N99 -1 7,
N12 0 0 en53,
N100 -1 -4,

N28 10 19 wn20,
N115 11 23,
N9 10 11 wn50,
N96 11 7,
N10 10 0 wn51,
N98 11 -4,

N37 18 13 en23,
N117 17 17,
N13 18 5 en54,
N101 17 1,
]])

   route(nl, x, y, [[
o -3 4 -3 15,
n20 13 4 13 15,
n23 6 -7 15 -7 15 9,
]])

   return nl
end


n = nodes_rect(1920, 4170, 2340, 3840)
local nl0ba = regsel_dual_driver(n, 2000, 3890, megabus_control.rhsel_00ba, megabus_control.rhsel_01ba)
local nl0bd = regsel_dual_driver(n, 2050, 3890, megabus_control.rhsel_00bd, megabus_control.rhsel_01bd)
local nl1ba = regsel_dual_driver(n, 2000, 3940, megabus_control.rhsel_10ba, megabus_control.rhsel_11ba)
local nl1bd = regsel_dual_driver(n, 2050, 3940, megabus_control.rhsel_10bd, megabus_control.rhsel_11bd)
local nlrba = regsel_dual_driver(n, 2000, 3990, megabus_control.rhsel_rdba, megabus_control.rhsel_raba)
local nlrbd = regsel_dual_driver(n, 2050, 3990, megabus_control.rhsel_rdbd, megabus_control.rhsel_rabd)
local nl20ba = regsel_dual_driver_t(n, 2000, 4040, megabus_control.rhsel_20ba, megabus_control.rhsel_21ba)
local nl20bd = regsel_dual_driver_t(n, 2050, 4040, megabus_control.rhsel_20bd, megabus_control.rhsel_21bd)
local nlr17h_abc = regsel_single_driver_it(n, 2000, 4120, megabus_control.r17h_abc)
local nlr17h_dbc = regsel_single_driver_it(n, 2050, 4120, megabus_control.r17h_dbc)

nl = match(n, [[
N0=t(n35, t_10, pch_dbc)
N1=t(pch_dbc, n14, n36)
N2=t(n15, n9, n37)
N3=d(n38, n38, t_8)
N4=t(pch_abc, t_9, n39)
N5=t(n40, n17, pch_abc)
N6=t(n18, n7, n41)
N7=d(n42, n42, t)
N8=d(pch_dbc, pch_dbc, n43)
N16=t(n44, t_10, t_8)
N17=t(t_8, i_10, n45)
N18=t(t_8, n14, n46)
N19=d(pch_abc, pch_abc, n47)
N20=t(t, t_9, n48)
N22=t(n49, i_9, t)
N23=t(t, n17, n55)
N24=t(n15, n7, n0)
N25=t(n18, n9, n0)
N26=t(n2, n1, t_10)
N27=t(n4, n1, t_9)
N38=t(n6, n7, n8)
N39=t(n19, n9, n6)
N40=t(i_8, n1, n8)
N41=t(n8, n9, n10)
N42=t(n19, n7, n10)
N43=t(n12, n1, i_10)
N44=t(n12, n9, n11)
N46=t(n16, n7, n11)
N47=t(n12, n7, n13)
N48=t(n16, n9, n13)
N49=t(n15, n1, n14)
N50=t(i_9, n1, n16)
N51=t(n18, n1, n17)
N53=t(n19, n1, i_7)
N54=t(n21, n7, n22)
N56=t(n21, n1, i_3)
N57=t(n21, n9, n24)
N60=t(n34, n9, n22)
N64=t(n34, n7, n24)
N65=t(i, n1, n25)
N66=t(n25, n9, n26)
N67=t(n25, n7, n27)
N68=t(n32, n7, n26)
N69=t(n32, n9, n27)
N70=t(n28, n7, n29)
N71=t(n28, n1, i_5)
N73=t(n28, n9, n30)
N74=t(n31, n9, n29)
N75=t(n31, n7, n30)
N76=t(n31, n1, i_6)
N77=t(i_2, n1, n32)
N78=t(i_4, n1, n34)
N79=gnd(n35)
N80=gnd(n36)
N81=gnd(n37)
N82=gnd(n38)
N83=gnd(n39)
N84=gnd(n40)
N85=gnd(n41)
N86=gnd(n42)
N87=vcc(n43)
N88=vcc(n44)
N89=vcc(n45)
N90=vcc(n46)
N91=vcc(n47)
N92=vcc(n48)
N93=vcc(n49)
N94=vcc(n55)
N95=t(n64, n57, n2)
N102=t(n67, n59, n2)
N103=t(n68, n56, n4)
N106=t(n4, n58, n69)
N107=t(n73, n61, n7)
N108=t(n74, n7, n9)
N109=t(n58, n57, n75)
N110=t(n76, n56, n59)
N111=t(n60, n58, n77)
N112=t(n80, n59, n60)
N113=d(n2, n2, n86)
N114=d(n4, n4, n87)
N120=d(n89, n7, n7)
N121=d(n9, n9, n90)
N122=d(n58, n58, n91)
N123=d(n59, n59, n92)
N124=d(n60, n60, n93)
N125=gnd(n64)
N126=gnd(n67)
N127=gnd(n68)
N128=gnd(n69)
N129=gnd(n73)
N130=gnd(n74)
N131=gnd(n75)
N134=gnd(n76)
N140=gnd(n77)
N141=gnd(n80)
N142=vcc(n86)
N143=vcc(n87)
N144=vcc(n89)
N145=vcc(n90)
N146=vcc(n91)
N147=vcc(n92)
N149=vcc(n93)
]], megabus_control)

move(nl, 0, 0, [[
N49 2110 4163 nn14,
N51 2110 4153 nn17,
N43 2110 4126 ni_10,
N26 2110 4116 nt_10,
N50 2110 4106 ni_9,
N27 2110 4096 nt_9,
N40 2110 4034 ni_8,
N53 2110 4024 ni_7,
N76 2110 3984 ni_6,
N71 2110 3974 ni_5,
N78 2110 3934 ni_4,
N56 2110 3924 ni_3,
N77 2110 3884 ni_2,
N65 2110 3874 ni,

N24 2130 4163 nn15,
N6  2130 4153 nn18,
N85 2134 4152,
N47 2130 4126 nn12,
N46 2130 4106 nn16,
N38 2130 4034 nn8,
N42 2130 4024 nn19,
N75 2130 3984 nn31,
N70 2130 3974 nn28,
N64 2130 3934 nn34,
N54 2130 3924 nn21,
N68 2130 3884 nn32,
N67 2130 3874 nn25,

N2  2150 4160 nn15,
N81 2154 4159,
N25 2150 4150 nn18,
N44 2150 4123 nn12,
N48 2150 4103 nn16,
N41 2150 4031 nn8,
N39 2150 4021 nn19,
N74 2150 3981 nn31,
N73 2150 3971 nn28,
N60 2150 3931 nn34,
N57 2150 3921 nn21,
N69 2150 3881 nn32,
N66 2150 3871 nn25,

N19 2000 4170 epch_abc,
N91 1999 4174,
N4  2000 4162 en39,
N83 1999 4158,
N5  2010 4162 en40,
N84 2009 4158,

N8  2050 4170 epch_dbc,
N87 2049 4174,
N0  2050 4162 en35,
N79 2049 4158,
N1  2060 4162 en36,
N80 2059 4158,

N7  2024 4064 en42,
N86 2023 4060,
N20 2017 4072 et,
N92 2016 4076,
N22 2024 4072 et,
N93 2023 4076,
N23 2031 4072 et,
N94 2030 4076,

N3  2074 4064 en38,
N82 2073 4060,
N16 2067 4072 et_8,
N88 2066 4076,
N17 2074 4072 et_8,
N89 2073 4076,
N18 2081 4072 et_8,
N90 2080 4076,

N123 2300 4161 en59,
N147 2299 4165,
N110 2300 4153 en76,
N134 2299 4149,

N113 2290 4165 en2,
N142 2289 4169,
N102 2290 4157 en67,
N126 2289 4153,

N114 2290 4104 en4,
N143 2289 4108,
N103 2290 4096 en68,
N127 2289 4092,

N124 2290 4068 en60,
N149 2289 4072,
N112 2290 4060 en80,
N141 2289 4056,

N122 2280 4132 en58,
N146 2279 4136,
N109 2280 4124 en75,
N131 2279 4120,

N95  2270 4157 en64,
N125 2269 4153,
N106 2270 4096 en69,
N128 2269 4092,
N111 2270 4060 en77,
N140 2269 4056,
]])

route(nl, 0, 0, [[
n1 2114 3878 2114 3888 2114 3928 2114 3938 2114 3978 2114 3988 2114 4028 2114 4038 2114 4100 2114 4110 2114 4120 2114 4130 2114 4157 2114 4167 2114 4184 2500 4184 3000 4184 3500 4184 4000 4184 4469 4184 4469 4212 4704 4212 2114 3484 2312 3484,
n7 2124 3878 2124 3888 2124 3928 2124 3938 2124 3978 2124 3988 2124 4028 2124 4038 2124 4100 2124 4110 2124 4120 2124 4130 2124 4157 2124 4167,
n9 2156 3875 2156 3885 2156 3925 2156 3935 2156 3975 2156 3985 2156 4025 2156 4035 2156 4097 2156 4107 2156 4117 2156 4127 2156 4154 2156 4164,

n14 2085 4162,
n17 2014 4152 2035 4152,
i_10 2078 4125,
t_10 2054 4111 2071 4111 2106 4111,
i_9 2022 4105 2028 4105,
t_9 2004 4103 2021 4103 2106 4103,

i_7 2020 4031 2106 4031,
i_6 2054 3983,
i_5 2004 3981 2106 3981 2106 3973,
i_4 2054 3933,
i_3 2004 3931 2106 3931 2106 3923,
i_2 2054 3883,
i   2004 3881 2106 3881 2106 3873,

n15 2126 4159,
n18 2126 4149,
n12 2126 4122,
n16 2126 4102,
n8  2126 4030,
n19 2126 4020,
n31 2126 3980,
n28 2126 3970,
n34 2126 3930,
n21 2126 3920,
n32 2126 3880,
n25 2126 3870,

n56 2304 4096,
n59 2297 4157 2297 4060,
n57 2286 4124 2286 4157,
n58 2274 4128,
n2 2267 4161 2267 4115,
n4 2267 4100 2267 4095,

n0 2140 4162 2140 4156 2154 4156 2158 4156 2158 4357 4416 4357 2518 3508 2518 4357,
n13 2134 4109 2154 4109 2538 3508 2158 4102 2158 4048 2538 4048,
n11 2136 4105 2136 4120 2154 4120 2160 4120 2160 4050 2497 4050,

pch_abc 1901 4166 1901 3558 1850 3558 1850 3550,
pch_dbc 2047 4166 2047 4154 1903 4154 1903 3564,
n10 2146 4023 2146 4028 2154 4028 2164 4028 2164 3670 2164 2400,
n29 2146 3973 2146 3978 2154 3978 2168 3978 2168 3730 2168 2400,
n22 2146 3923 2146 3928 2154 3928 2162 3928 2162 3640 2162 2400,
n27 2146 3873 2146 3878 2154 3878 2166 3878 2166 3700 2166 2400,
n6  2134 4018 2154 4018 2134 2550 2134 2522 2154 2522,
n30 2136 3983 2136 3968 2154 3968 2136 2524 2156 2524,
n24 2138 3933 2138 3918 2154 3918 2138 2526 2158 2526,
n26 2140 3883 2140 3868 2154 3868 2140 2528 2160 2528,
n60 2090 4064 2090 3470 1910 3470 1910 3175 1756 3175,
]])


local n = nodes_rect(1765, 3635, 1840, 3570)
local nl = match(n, [[
N0=t(h, a, c)
N1=t(i, b, d)
N2=t(j, c, d)
N3=t(k, a, e)
N4=t(l, f, e)
N5=t(m, b, f)
N6=t(n, c, g)
N7=t(o, f, g)
N8=d(c, c, p)
N9=d(d, d, q)
N10=d(r, e, e)
N11=d(f, f, s)
N12=d(t, g, g)
N13=gnd(h)
N14=gnd(i)
N15=gnd(j)
N16=gnd(k)
N17=gnd(l)
N18=gnd(m)
N19=gnd(n)
N20=gnd(o)
N21=vcc(p)
N22=vcc(q)
N23=vcc(r)
N24=vcc(s)
N25=vcc(t)
]])
move(nl, 0, 0, [[
N9  1770 3608 wd,
N22 1771 3612,
N2  1780 3600 wj,
N15 1781 3596,
N1  1810 3600 wi,
N14 1811 3596,

N10 1770 3593 we,
N23 1771 3597,
N4  1790 3585 wl,
N17 1791 3581,
N3  1800 3585 wk,
N16 1801 3581,

N12 1770 3579 wg,
N25 1771 3583,
N6  1780 3571 wn,
N19 1781 3567,
N7  1790 3571 wo,
N20 1791 3567,

N8  1820 3606 wc,
N21 1821 3610,
N0  1826 3606 eh,
N13 1825 3602,

N11 1820 3591 wf,
N24 1821 3595,
N5  1826 3591 em,
N18 1825 3587,
]])

route(nl, 0, 0, [[
c 1776 3606 1823 3602 1823 3610,
f 1786 3591 1823 3587 1823 3595,
a 1832 3606 1832 3578 1796 3578,
b 1830 3584 1806 3584,
]])


local n = nodes_rect(1900, 3615, 1920, 3585)
local nl = simple_driver_inverted(n, 1850, 3600)
nl.i:route(1861, 3600, 1861, 3624, 1757, 3624, 1757, 3376, 1757, 3362, 1916, 3362, 1916, 2459)
nl.o:route(1850, 3622, 1755, 3622)

local n = nodes_rect(1650, 3445, 1745, 3425)
local nl = match(n, "A=t(a, b, d) B=t(b, c, e) C=d(f, b, b) D=gnd(d) E=gnd(e) F=vcc(f)")
move(nl, 0, 0, "A 1580 3436 ed, D 1579 3432, C 1589 3436 wb, F 1590 3440, B 1595 3436 ee, E 1594 3432")
route(nl, 0, 0, "b 1592 3440 1592 3432, c 1599 3429 516 3429, a 1568 3430")


local nl = rw_driver(nodes_rect(1630, 3480, 1780, 3435), 1670, 3456, 0)
route(nl, 0, 0, [[
b 1694 3494 1694 3467 1694 3425,
c 1664 3456 1664 3560 1664 3653 1664 3680 1664 3707 1664 3734 1664 3761 1664 3788 1664 3815 1664 3842 1664 3869 1664 3896 1664 3923 1664 3950 1664 3977 1664 4004 1664 4031 1664 4058 1664 4085 1664 4112,
a 1666 3533 1666 3589 1666 3506 1666 3618 1666 3445 1666 3403,
]])

local nl = rw_driver(nodes_rect(1630, 3420, 1780, 3385), 1670, 3414, 0)

local n = nodes_rect(1620, 3390, 1790, 3195)

function pp_dual_drive(n, x, y, od, oi)
   local nl = match(n, [[
T1=t(v1, i, od)
V1=vcc(v1)
T2=t(od, ii, g1)
G1=gnd(g1)

T3=d(ii, ii, v2)
V2=vcc(v2)
T4=t(g2, i, ii)
G2=gnd(g2)

T5=t(oi, ii, v3)
V3=vcc(v3)
T6=t(g3, i, oi)
G3=gnd(g3)
]], { od=od, oi=oi })

   move(nl, x, y, [[
T1  0   0 eod,
V1 -1   4,
T2  0  -8 eg1,
G1 -1 -12,

T3 12 -10 wii,
V2 13  -6,
T4 12 -18 wg2,
G2 13 -22,

T5  0 -20 eoi,
V3 -1 -16,
T6  0 -28 eg3,
G3 -1 -32,
]])
   route(nl, x, y, [[
i 4 -18 4 -23 8 -20,
ii 6 -8 6 -10 6 -20,
]])
   return nl.i
end

function pp_direct_drive(n, x, y, od)
   local nl = match(n, [[
T1=t(v1, i, od)
V1=vcc(v1)
T2=t(od, ii, g1)
G1=gnd(g1)

T3=d(ii, ii, v2)
V2=vcc(v2)
T4=t(g2, i, ii)
G2=gnd(g2)
]], { od=od })

   move(nl, x, y, [[
T1  0   0 eod,
V1 -1   4,
T2  0  -8 eg1,
G1 -1 -12,

T3 10   0 wii,
V2 11   4,
T4 10  -8 wg2,
G2 11 -12,
]])
   route(nl, x, y, [[
]])
   return nl.i
end

function pp_inverted_drive(n, x, y, od)
   local nl = match(n, [[
T1=t(v1, ii, od)
V1=vcc(v1)
T2=t(od, i, g1)
G1=gnd(g1)

T3=d(ii, ii, v2)
V2=vcc(v2)
T4=t(g2, i, ii)
G2=gnd(g2)
]], { od=od })

   move(nl, x, y, [[
T1  0   0 eod,
V1 -1   4,
T2  0  -8 eg1,
G1 -1 -12,

T3  8   0 wii,
V2  9   4,
T4  8  -8 wg2,
G2  9 -12,
]])
   route(nl, x, y, [[
]])
   return nl.i
end

function pp_bi_inverted_drive(n, x, y, od)
   local nl = match(n, [[
T1=t(v1, iii, od)
V1=vcc(v1)
T2=t(od, ii, g1)
G1=gnd(g1)

T3=d(iii, iii, v2)
V2=vcc(v2)
T4=t(g2, ii, iii)
G2=gnd(g2)

T5=d(ii, ii, v3)
V3=vcc(v3)
T6=t(g3, i, ii)
G3=gnd(g3)
]], { od=od })

   move(nl, x, y, [[
T1  0   0 eod,
V1 -1   4,
T2  0  -8 eg1,
G1 -1 -12,

T3  8   0 wiii,
V2  9   4,
T4  8  -8 wg2,
G2  9 -12,

T5 16   0 eii,
V3 15   4,
T6 16  -8 eg3,
G3 15 -12,
]])
   route(nl, x, y, [[
ii 12 -4 12 -16 4 -16,
]])
   return nl.i
end

pp_dual_drive(n, 1720, 3390, megabus.aluh_ab_in, megabus.aluh_cst_in)
pp_direct_drive(n, 1700, 3360, megabus.aluh_cst_val)
pp_direct_drive(n, 1730, 3345, megabus.ha_active)
pp_direct_drive(n, 1700, 3335, megabus.hd_active)

function r18_driver(n, x, y, o, i1, i2)
   local nl = match(n, [[
N14=t(o, t, n51)
N79=gnd(n51)

N45=t(o, n22, n0)
N59=t(n22, n85, n23)
N113=vcc(n85)
N20=t(n23, t, n57)
N85=gnd(n57)
N40=d(n23, n23, n77)
N105=vcc(n77)
N19=t(n23, i1, n56)
N84=gnd(n56)

N47=t(o, n26, n1)
N62=t(n26, n86, n27)
N114=vcc(n86)
N22=t(n27, t, n59)
N87=gnd(n59)
N41=d(n27, n27, n78)
N106=vcc(n78)
N23=t(n27, i2, n60)
N88=gnd(n60)
]], { o=o, i1=i1, i2=i2} )
   move(nl, x, y, [[
N14   0   0 en51,
N79  -1  -4,

N45   5   3 so,
N59  17   0 nn22,
N113 17   4,
N20  25   0 nn23,
N85  29  -1,
N40  35  -1 wn23,
N105 36   3,
N19  41  -1 en56,
N84  40  -5,

N47   5   7 no,
N62  17  12 nn26,
N114 17  16,
N22  25  10 sn27,
N87  29  11,
N41  35  11 wn27,
N106 36  15,
N23  41  11 en60,
N88  40   7,
]])
   route(nl, x, y, [[
n23 21 -5 31 -5 38 -5 38 3,
n27 21 15 31 15 38 15 38 7,
t  13 0 13 7 21 7 21 5 25 5 45 5,
]])
   return nl
end

function f_inverted(n, x, y, i)
   local nl = match(n, "A=t(o,i,g) B=d(v,o,o) V=vcc(v) G=gnd(g)", { i=i })
   move(nl, x, y, "A 0 0 wg, B 6 0 eo, G 1 -4, V 5 4")
   route(nl, x, y, "o 3 4 3 -4")
   return nl.o
end

function inverted(n, x, y, o)
   local nl = match(n, "A=t(o,i,g) B=d(v,o,o) V=vcc(v) G=gnd(g)", { o=o })
   move(nl, x, y, "A 6 0 eg, B 0 0 wo, G 5 -4, V 1 4")
   route(nl, x, y, "o 3 4 3 -4")
   return nl.o
end

local n1 = nodes_rect(1755, 3288, 1755, 3288)[1]
local nl1 = match(n, "A=d(v,o,o) B=t(o,i2,g) C=t(i2,t,i1) V=vcc(v) G=gnd(g)", { A = n1 })
move(nl1, 1630, 3313, [[
A 55 -6 wo,
V 56 -2,
B 61 -6 eg,
G 60 -10,
C 155 -5 ni2,
]])
route(nl1, 1630, 3313, [[
o 45 -6 58 -2 58 -10,
t 151 -1,
]])
-- nano 57
local nl2 = r18_driver(n, 1630, 3313, megabus.r18h_dbc, nl1.o, nil)
local nl3 = match(n, "C=t(i2,t,i1)", { i2 = nl2.i2 })
move(nl3, 0, 0, "C 1785 3325 ni2")
route(nl3, 0, 0, "t 1781 3329")

local nl3 = match(n, "C=t(i2,t,i1)", { i2 = nl2.t })
move(nl3, 0, 0, "C 1785 3319 ni2")
route(nl3, 0, 0, "t 1781 3323")

-- nano 57
local nl2 = r18_driver(n, 1630, 3289, megabus.r18h_abc, nil, nl1.o)
local nl3 = match(n, "C=t(i2,t,i1)", { i2 = nl2.i1 })
move(nl3, 0, 0, "C 1785 3289 ni2")
route(nl3, 0, 0, "t 1781 3293")

-- nano 58
local nl3 = match(n, "C=t(i2,t,i1)", { i2 = nl2.t })
move(nl3, 0, 0, "C 1785 3295 ni2")
route(nl3, 0, 0, "t 1781 3299")

megabus_control.hd_sense_amp_keep = drive_0_2d(n, 1670, 3264, megabus.hd_sense_amp_keep)
megabus_control.ha_sense_amp_keep = drive_1_2d(n, 1670, 3264, megabus.ha_sense_amp_keep)
megabus.ld_sense_amp_keep:route(1690, 3246, 1664, 3246, 1630, 3246, 1630, 3035, 1630, 3006, 1622, 3006, 1622, 2183, 1622, 2013, 1692, 2013, 1692, 1968)

-- nano 55
local nl1 = match(n, "A=d(v,o,o) B=t(o,i2,g) C=t(i2,t,i1) V=vcc(v) G=gnd(g)", { o = megabus_control.hd_sense_amp_keep })
move(nl1, 1755, 3282, "A 0 0 wo,V 1 4,B 6 0 eg,G 5 -4,C 30 1 ni2")
route(nl1, 1755, 3282, "o 3 4 3 -4 -49 0 -44 0 -48 -9, t 26 5")

-- nano 54
local nl1 = match(n, "A=d(v,o,o) B=t(o,i2,g) C=t(i2,t,i1) V=vcc(v) G=gnd(g)", { o = megabus_control.ha_sense_amp_keep })
move(nl1, 1755, 3268, "A 0 0 wo,V 1 4,B 6 0 eg,G 5 -4,C 30 1 ni2")
route(nl1, 1755, 3268, "o 3 4 3 -4 -19 0, t 26 5")


local n = nodes_rect(1794, 3372, 1834, 3246)
local nl = match(n, [[
N0=t(i, f, d)
N1=t(e, f, j)
N2=t(k, a, f)
N3=t(l, b, f)
N4=t(f, c, m)
N5=t(g, c, n)
N6=t(o, f, g)
N7=t(p, g, h)
N8=t(q, e, d)
N9=d(e, e, r)
N10=d(s, f, f)
N11=d(t, g, g)
N12=d(u, h, h)
N13=gnd(i)
N14=gnd(j)
N15=gnd(k)
N16=gnd(l)
N17=gnd(m)
N18=gnd(n)
N19=gnd(o)
N20=gnd(p)
N21=vcc(q)
N22=vcc(r)
N23=vcc(s)
N24=vcc(t)
N25=vcc(u)
a~latched_nano.58
b~latched_nano.57
c~latched_nano.56
]])
move(nl, 0, 0, [[
N10 1860 3315 ef,
N23 1859 3319,
N2  1840 3307 ek,
N15 1839 3303,
N3  1850 3307 el,
N16 1849 3303,
N4  1860 3307 em,
N17 1859 3303,

N8  1833 3338 ed,
N21 1832 3342,
N0  1833 3330 ei,
N13 1832 3326,
N9  1841 3338 we,
N22 1842 3342,
N1  1841 3330 wj,
N14 1842 3326,

N11 1831 3298 eg,
N24 1830 3302,
N6  1831 3290 eo,
N19 1830 3286,
N5  1821 3290 en,
N18 1820 3286,

N12 1810 3318 wh,
N25 1811 3322,
N7  1816 3318 ep,
N20 1815 3314,
]])
route(nl, 0, 0, [[
f 1837 3311 1837 3290,
h 1813 3322 1813 3314,
]])

local n = nodes_rect(1630, 3200, 1775, 3070)
local nl1 = pp_bi_inverted_drive(n, 1670, 3200, megabus.hl_a_connect)
local nl2 = pp_bi_inverted_drive(n, 1670, 3170, megabus.hl_d_connect)
local nl3 = pp_direct_drive(     n, 1670, 3140, megabus.alul_bit_2p)
local nl4 = pp_dual_drive(       n, 1670, 3110, megabus.alul_ab_in, megabus.alul_cst_in) 

megabus.hl_a_connect:route(1620, 3196, 1620, 3158)
megabus.hl_d_connect:route(1622, 3166, 1622, 3140)

megabus.alul_bit_2p:route(1620, 3136)
megabus.alul_ab_in:route(1622, 3106, 1622, 3014)
megabus.alul_cst_in:route(1624, 3086, 1624, 3016)

local nl = match(n, [[
T1=t(o1, t, i1)
T2=t(o2, t, i2)
]], { o1 = nl1, o2 = nl2 })
move(nl, 0, 0, [[
T1 1785 3193 no1,
T2 1785 3163 no2,
]])
route(nl, 0, 0, [[
t 1781 3197 1781 3167 1781 3218
]])

local n = nodes_rect(1790, 3265, 1950, 3085)
local nl = match(n, [[
N0=t(n25, n6, n5)
N1=t(n5, n11, n26)
N2=t(n27, n13, n5)
N3=t(n6, n12, n28)
N4=t(n8, n11, n29)
N5=t(n10, n6, n30)
N6=t(n13, n14, n31)
N7=t(n32, n15, n16)
N8=t(n16, n17, n33)
N9=t(n23, n16, n18)
N10=t(n24, n19, n22)
N11=d(n5, n5, n34)
N12=d(n6, n6, n35)
N13=d(n36, n7, n7)
N14=d(n8, n8, n37)
N15=d(n38, n13, n13)
N16=d(n16, n16, n39)
N17=d(n18, n18, n40)
N18=d(n21, n21, n41)
N19=t(n1, n0, n15)
N20=t(n2, n0, n9)
N21=t(n14, n0, n2)
N22=t(n2, n0, n20)
N23=t(n3, n0, n12)
N24=t(n4, n0, n11)
N25=t(n6, n16, n19)
N26=t(n7, n9, n10)
N27=t(n11, n18, n19)
N28=t(n21, n20, n22)
N29=gnd(n23)
N30=gnd(n24)
N31=gnd(n25)
N32=gnd(n26)
N33=gnd(n27)
N34=gnd(n28)
N35=gnd(n29)
N36=gnd(n30)
N37=gnd(n31)
N38=gnd(n32)
N39=gnd(n33)
N40=vcc(n34)
N41=vcc(n35)
N42=vcc(n36)
N43=vcc(n37)
N44=vcc(n38)
N45=vcc(n39)
N46=vcc(n40)
N47=vcc(n41)
n0~precharge
n2~latched_nano.51
n3~latched_nano.50
n4~latched_nano.49
]])

move(nl, 1785, 3076, [[
N24   0  0 nn11,
N23   0 20 nn12,
N20   0 40 nn9,
N22   0 60 nn20,
N21   0 80 nn14,

N11 -20  7 en5,
N40 -21 11,
N1  -20 -1 en26,
N32 -21 -5,
N0  -26 -1 wn25,
N31 -25 -5,
N2  -36 -1 wn27,
N33 -35 -5,

N14 -50  7 en8,
N43 -51 11,
N4  -50 -1 en29,
N35 -51 -5,

N12 -10 27 en6,
N41 -11 31,
N3  -10 19 en28,
N34 -11 15,

N13 -20 47 en7,
N42 -21 51,
N26 -20 39 en10,
N5  -20 31 en30,
N36 -21 27,

N18 -34 67 en21,
N47 -35 71,
N28 -34 59 en22,
N10 -34 51 en24,
N30 -35 47,

N25 -31 32 wn6,

N16 -43 32 en16,
N45 -44 36,
N7  -43 24 en32,
N38 -44 20,
N8  -49 24 wn33,
N39 -48 20,

N19 -33 80 nn15,

N27 -60 32 en11,

N17 -55 36 en18,
N46 -56 40,
N9  -55 28 en23,
N29 -56 24,

N15 -20 75 en13,
N44 -21 79,
N6  -20 67 en31,
N37 -21 63,
]])

route(nl, 1785, 3076, [[
n0 -4 4 -4 24 -4 44 -4 64 -4 84,
n6 -30 23 -16 23 -30 18 -63 18,
n11 -16 -8 -46 -8 -61 -8,
n15 -37 24,
n19 -61 45 -30 45,
n7 -63 43,
n14 -6 79 -6 67,
n13 -28 71 -28 5 -40 5,
n17 -53 -10,
n5 -35 14 -63 14,
]])


nl.n6:route(1720, 3094, 1720, 3125, 1676, 3125, 1720, 3255, 1714, 3255, 1714, 3345, 1706, 3345)
nl.n5:route(1678, 3085, 1722, 3085, 1722, 3255, 1728, 3255, 1728, 3284, 1724, 3284)
nl.n7:route(1626, 3119, 1626, 3008)
nl.n8:route(1722, 3079, 1722, 3075, 1628, 3075, 1628, 3010)
nl.n21:route(1718, 3139, 1718, 3123, 1618, 3123, 1618, 3076)
nl.n17:route(1871, 3066)

local n = nodes_rect(1920, 3665, 1990, 3565)
local nl = match(n, [[
N0=t(a, c, h)
N1=t(d, b, i)
N2=t(j, a, d)
N3=t(k, a, e)
N4=t(l, f, e)
N5=t(m, b, f)
N6=t(n, c, g)
N7=t(g, f, o)
N8=d(a, a, p)
N9=d(q, d, d)
N10=d(e, e, r)
N11=d(f, f, s)
N12=d(g, g, t)
N13=gnd(h)
N14=gnd(i)
N15=gnd(j)
N16=gnd(k)
N17=gnd(l)
N18=gnd(m)
N19=gnd(n)
N20=gnd(o)
N21=vcc(p)
N22=vcc(q)
N23=vcc(r)
N24=vcc(s)
N25=vcc(t)
b~latched_nano.47
c~latched_nano.46
]])
move(nl, 1870, 3550, [[
N10  0   0 we,
N23  1   4,
N3   2  -8 ek,
N16  1 -12,
N4   9  -8 el,
N17  8 -12,

N12  0 -20 wg,
N25  1 -16,
N6   2 -28 en,
N19  1 -32,
N7   9 -28 eo,
N20  8 -32,

N9   0 -40 wd,
N22  1 -36,
N1   2 -48 ei,
N14  1 -52,
N2   9 -48 ej,
N15  8 -52,

N11 30 -18 wf,
N24 31 -14,
N5  36 -18 em,
N18 35 -22,

N8  30 -38 wa,
N21 31 -34,
N0  36 -38 eh,
N13 35 -42,
]])
route(nl, 1870, 3550, [[
f 15 -8 15 -18 15 -28 33 -14 33 -22,
a 6 -15 13 -15 13 -38 33 -34 33 -42,
b 40 -30 15 -30 15 -42 6 -42,
c 40 -45 17 -45 17 -36 6 -36,
g -14 -20 -14 -27,
e -14 0 -14 -13,
]])


local n = nodes_rect(2220, 4045, 2240, 4025)
local nl = match(n, "A=t(c, b, a) B=d(d, a, a) C=gnd(c) D=vcc(d)")
move(nl, 2287, 4012, "B 0 0 wa, D 1 4, A 6 0 ec, C 5 -4")
route(nl, 2287, 4012, "a 3 4 3 -4")
nl.a:route(2280, 4012, 2124, 4012)

local n = nodes_rect(2220, 4015, 2250, 3995)
local nl = match(n, "A=t(c, b, a) B=d(d, a, a) C=gnd(c) D=vcc(d)")
move(nl, 2270, 4000, "B 0 0 wa, D 1 4, A 6 0 ec, C 5 -4")
route(nl, 2270, 4000, "a 3 4 3 -4")
nl.a:route(2156, 4000)

local map = {}
local steps = { 3737, 3711, 3676, 3644, 3611 }
local nn = {}
for i=0,3 do
   nn[i] = nodes_rect(2180, steps[i+1], 2270, steps[i+2])
end
for i=0,3 do
   local nl = match(nn[i], [[
A=t(a, e, g)
B=t(d, e, h)
C=t(i, b, e)
D=t(j, c, e)
E=t(k, f, e)
F=t(a, d, l)
G=d(d, d, m)
H=d(e, e, n)
I=gnd(g)
J=gnd(h)
K=gnd(i)
L=gnd(j)
M=gnd(k)
N=vcc(l)
O=vcc(m)
P=vcc(n)
]])
   move(nl, 2190, 3730-30*i, [[
F 1 4 ea,
N 0 8,
A 1 -4 eg,
I 0 -8,
G 9 4 wd,
O 10 8,
B 9 -4 wh,
J 10 -8,

H 20 4 we,
P 21 8,
C 20 -4 wi,
K 21 -8,
D 30 -4 wj,
L 31 -8,
E 40 -4 wk,
M 41 -8,
]])
   route(nl, 2190, 3730-30*i, [[
e 12 4 12 -12 5 -12 5 -9 12 -5,
b 14 -4,
]])
   map[string.format("c%d", i)] = nl.f
   
   
   
end

local n = nodes_rect(2300, 3725, 2555, 3537)
n = merge(n, nodes_rect(2220, 3575, 2350, 3515))
local nl = match(n, [[
N0=t(n28, n16, n0)
N1=t(n2, n9, n29)
N2=t(n30, n13, n2)
N3=t(n31, n14, n3)
N4=t(n25, n19, n42)
N5=t(n43, n26, n25)
N6=t(n8, n9, n32)
N7=t(n10, n5, n33)
N8=t(n10, n4, n34)
N9=t(n35, n7, n11)
N10=t(n4, n12, n36)
N11=t(n14, n17, n37)
N12=t(n15, n9, n38)
N13=t(n15, n13, n39)
N14=t(n16, n18, n40)
N15=t(n19, n24, n41)
N16=t(n27, n19, n44)
N17=t(n45, n25, n27)
N18=t(n0, n18, n48)
N19=t(n2, n15, n49)
N20=t(n3, n17, n50)
N21=d(n8, n8, n51)
N22=d(n4, n4, n52)
N23=d(n53, n14, n14)
N24=d(n15, n15, n54)
N25=d(n55, n16, n16)
N26=d(n19, n19, n56)
N27=d(n57, n25, n25)
N28=d(n27, n27, n58)
N29=t(n8, n1, n10)
N30=t(c0, n19, n23)
N31=t(n10, n6, n11)
N32=t(c1, n19, n22)
N33=t(c2, n19, n20)
N34=t(c3, n19, n21)
N35=gnd(n28)
N36=gnd(n29)
N37=gnd(n30)
N38=gnd(n31)
N39=gnd(n32)
N40=gnd(n33)
N41=gnd(n34)
N42=gnd(n35)
N43=gnd(n36)
N44=gnd(n37)
N45=gnd(n38)
N46=gnd(n39)
N47=gnd(n40)
N48=gnd(n41)
N49=gnd(n42)
N50=gnd(n43)
N51=gnd(n44)
N52=gnd(n45)
N53=gnd(n46)
N54=gnd(n47)
N55=vcc(n48)
N56=vcc(n49)
N57=vcc(n50)
N58=vcc(n51)
N59=vcc(n52)
N60=vcc(n53)
N61=vcc(n54)
N62=vcc(n55)
N63=vcc(n56)
N64=vcc(n57)
N65=vcc(n58)
n5~latched_nano.45
n6~latched_nano.60
n7~latched_nano.59
n9~latched_nano.43
]], map)

move(nl, 2280, 3660, [[
N21  0  8 en8,
N58 -1 12,
N6   0  0 en32,
N39 -1 -4,
N29  8  9 nn8,
N7  13  4 en33,
N40 12  0,
N8  23  4 en34,
N41 22  0,
N31 33  4 en11,
N9  33 -4 en35,
N42 32 -8,
N22 23 -16 en4,
N59 22 -12,
N10 23 -24 en36,
N43 22 -28,
]])

nl.n8:route(2277, 3664, 2277, 3772, 1958, 3772, 1958, 3372)
nl.c0:route(2256, 3623, 2142, 3623, 2142, 3445)
nl.c1:route(2246, 3621, 2144, 3621, 2144, 3405)
nl.c2:route(2236, 3619, 2146, 3619, 2146, 3325)
nl.c3:route(2226, 3617, 2148, 3617, 2148, 3365)
nl.n25:route(2150, 3600, 2150, 3450)
nl.n27:route(2152, 3576, 2152, 3430)
nl.n1:route(2288, 3770, 2160, 3770, 2160, 3675, 2160, 3256, 2233, 3256)

move(nl, 2227, 3600, [[
N34   0   0 en21,
N33  10   0 en20,
N32  20   0 en22,
N30  30   0 en23,
N26  50  -4 wn19,
N63  51   0,
N15  52 -12 en41,
N48  51 -16,
N27 -10   4 en25,
N64 -11   8,
N4  -10  -4 en42,
N49 -11  -8,
N5  -20  -4 en43,
N50 -21  -8,
N28 -10 -20 en27,
N65 -11 -16,
N16 -10 -28 en44,
N51 -11 -32,
N17 -20 -28 en45,
N52 -21 -32,
]])

route(nl, 2227, 3600, [[
c2  9 49 -1 49,
c1 19 79 -1 79,
c0 29 109 -1 109,
n19 -4 -4 -4 -28 4 -4 14 -4 24 -4 34 -4,
n25 -14 -28 -14 0,
]])

move(nl, 2540, 3500, [[
N20  1 12 en3,
N57  0 16,
N3   1  4 en31,
N38  0  0,
N23 11 12 wn14,
N60 12 16,
N11 11  4 wn37,
N44 12  0,
]])
nl.n17:route(2547, 3489)

move(nl, 2520, 3500, [[
N18  1 12 en0,
N55  0 16,
N0   1  4 en28,
N35  0  0,
N25 11 12 wn16,
N62 12 16,
N14 11  4 wn40,
N47 12  0,
]])
nl.n18:route(2527, 3478)

move(nl, 2500, 3520, [[
N19  0   0 en2,
N56 -1   4,
N1   0  -8 en29,
N36 -1 -12,
N2  -2 -16 en30,
N37 -3 -20,
N24  8   0 wn15,
N61  9   4,
N12  8  -8 wn38,
N45  9 -12,
N13 10 -16 wn39,
N46 11 -20,
]])
route(nl, 2500, 3520, [[
n2 -3 -4,
n15 11 -4,
n13 6 -53,
]])


local n = nodes_rect(1800, 3446, 1860, 3386)
local nl = pp_bi_inverted_drive(n, 1760, 3380)
local nl1 = match(n, "A=t(i, t, i0)", { i = nl })
nl1.A:move(1785, 3373, "n", nl.i)
nl1.t:route(1781, 3377)

local n = nodes_rect(1650, 3065, 1820, 2965)
n = merge(n, nodes_rect(1830, 3085, 1890, 2985))
local nl = match(n, [[
N0=c(n4, n3)
N1=t(n2, n10, n19)
N2=t(n4, n10, n14)
N3=t(n5, n0, n15)
N4=t(n16, n13, n7)
N5=t(n17, n5, n8)
N6=t(n18, n8, n9)
N7=t(n20, n12, n10)
N8=t(n21, n9, n11)
N9=t(n12, n1, n22)
N10=t(n23, n11, n13)
N11=t(n2, n3, n24)
N12=t(n4, n3, n25)
N13=d(n5, n5, n26)
N14=t(n6, n1, n27)
N15=t(n7, n11, n28)
N16=t(n29, n0, n8)
N17=d(n9, n9, n30)
N18=t(n31, n1, n10)
N19=t(n32, n8, n11)
N20=t(n33, n7, n12)
N21=d(n34, n13, n13)
N22=t(n3, n6, n7)
N23=t(n6, n7, n10)
N24=gnd(n14)
N25=gnd(n15)
N26=gnd(n16)
N27=gnd(n17)
N28=gnd(n18)
N29=gnd(n19)
N30=gnd(n20)
N31=gnd(n21)
N32=gnd(n22)
N33=gnd(n23)
N34=vcc(n24)
N35=vcc(n25)
N36=vcc(n26)
N37=vcc(n27)
N38=vcc(n28)
N39=vcc(n29)
N40=vcc(n30)
N41=vcc(n31)
N42=vcc(n32)
N43=vcc(n33)
N44=vcc(n34)
]])

move(nl, 1680, 3035, [[
N11  1   4 en2,
N34  0   8,
N1   1  -4 en19,
N29  0  -8,

N12 16   4 en4,
N35 15   8,
N2  16  -4 en14,
N24 15  -8,

N0   8   2 nn4,

N18 31  -7 en10,
N41 30  -3,
N7  31 -15 en20,
N30 30 -19,

N14 31  15 en6,
N37 30  19,
N23 31   7 en10,

N22 21  15 en3,

N20 41 -11 en12,
N43 40  -7,
N9  41 -19 en22,
N32 40 -23,

N15 51  -7 en7,
N38 50  -3,
N4  51 -15 en16,
N26 50 -19,
N21 61  -7 wn13,
N44 62  -3,
N10 61 -15 wn23,
N33 62 -19,

N19 67  -7 en11,
N42 66  -3,
N8  67 -15 en21,
N31 66 -19,
N17 77  -7 wn9,
N40 78  -3,
N6  77 -15 wn18,
N28 78 -19,

N16 83  -7 en8,
N39 82  -3,
N5  83 -15 en17,
N27 82 -19,
N13 93  -7 wn5,
N36 94  -3,
N3  93 -15 wn15,
N25 94 -19,

]])

route(nl, 1680, 3035, [[
n4 8 0,
n3 8 4 8 11 20 11,
n10 8 -4 8 -11 20 -11 30 0 28 0 28 -11,
n7 20 22 35 22 45 7,
n6 25 11,
n1 37 15 37 -7 37 -4 47 -4 47 -19 101 15,
n11 64 -11 64 -22 57 -22,
n8 80 -11 80 -22 73 -22,
n0 89 -29,
]])


local n = nodes_rect(1640, 2950, 1850, 2680)

megabus.aul_alul_w:route(1639, 2979, 1639, 2964)
megabus.aobl0:route(1890, 2804, 1890, 1773, 1930, 1773)

megabus_control.aul_alul_w = drive_1_2id(n, 1670, 2985, megabus.aul_alul_w)
megabus_control.aul_a_w = drive_0_2e(n, 1670, 2956, megabus.aul_a_w)
megabus_control.aul_d_w = drive_1_2e(n, 1670, 2956, megabus.aul_d_w)

megabus_control.aobl_0_test = feedback(n, 1700, 2925, megabus.aobl_0_test)
megabus_control.aobl_0_test:route(2350, 2933, 2350, 2116, 2792, 2116, 2792, 1430)

megabus_control.pcl_aul_w = drive_1_2e(n, 1670, 2917, megabus.pcl_aul_w)
megabus_control.pcl_dbc = drive_0_2id(n, 1670, 2890, megabus.pcl_dbc)
megabus_control.pcl_abc = drive_1_2id(n, 1670, 2890, megabus.pcl_abc)
megabus_control.aobl_aul_w = drive_0_2e(n, 1670, 2862, megabus.aobl_aul_w)
megabus_control.aobl_a_w = drive_1_2e(n, 1670, 2862, megabus.aobl_a_w)
megabus_control.aobl_d_w = drive_0_2e(n, 1670, 2832, megabus.aobl_d_w)
megabus_control.aobl_r = drive_1_1id(n, 1670, 2792, megabus.aobl_r)
megabus_control.eu_mvm_w = drive_0_2e(n, 1670, 2763, megabus.eu_mvm_w)
megabus_control.eu_mvm_step = drive_1_2e(n, 1670, 2763, megabus.eu_mvm_step)

megabus_control.eu_mvm_step:route(1942, 2757, 1942, 3239, 1965, 3239, 1965, 3398, 2029, 3398, 1965, 3466, 2209, 3466, 2209, 3258, 2307, 3258, 2307, 3218, 2070, 3466, 2040, 3466, 2000, 3466, 1965, 3446, 1965, 3426, 1965, 3406, 2009, 3398, 1989, 3398, 1969, 3398, 2020, 3466, 2029, 3416, 1980, 3466)
megabus_control.eu_mvm_w:route(1924, 2771, 1924, 2970, 2172, 2970, 2172, 3174, 1757, 2771, 1757, 2639, 1757, 2654, 1695, 2656, 1695, 2620)
megabus_control.aobl_r:route(2314, 3405, 2314, 3482, 1830, 3482, 1830, 3334, 1759, 3482, 1759, 3616, 1749, 3616, 1749, 3620, 1791, 3334, 1791, 2786)

megabus_control.cc_end = feedback(n, 1700, 2729, megabus.cc_end)

megabus_control.cc_end:route(1910, 2737, 1910, 2812, 2352, 2812, 2352, 2118, 2794, 2118, 2794, 1414)
megabus_control.pcl_dbc:route(1914, 2898, 1914, 2528, 2027, 2528)
megabus_control.pcl_abc:route(1912, 2884, 1912, 2562, 2067, 2562)

local nl = match(n, [[
N0=t(n6, n4, n12)
N1=t(aul_a_w, n3, n13)
N2=t(n14, n6, aul_a_w)
N3=t(n8, n3, n15)
N4=t(n16, n4, aul_d_w)
N5=t(aul_d_w, n8, n17)
N6=t(pcl_aul_w, n6, n18)
N7=t(n19, n8, pcl_aul_w)
N8=t(n20, n1, n9)
N9=t(n21, n9, aobl_aul_w)
N10=t(aobl_aul_w, n10, n22)
N11=t(n23, n2, n10)
N12=t(aobl_a_w, n1, n24)
N13=t(aobl_a_w, n10, n25)
N14=t(n26, n2, aobl_d_w)
N15=t(aobl_d_w, n9, n27)
N16=d(aul_alul_w, aul_alul_w, n28)
N17=d(n6, n6, n29)
N18=d(aul_a_w, aul_a_w, n30)
N19=d(n31, n8, n8)
N20=d(n32, aul_d_w, aul_d_w)
N21=d(n33, pcl_aul_w, pcl_aul_w)
N22=d(n9, n9, n34)
N23=d(aobl_aul_w, aobl_aul_w, n35)
N24=d(n10, n10, n36)
N25=d(aobl_a_w, aobl_a_w, n37)
N26=d(aobl_d_w, aobl_d_w, n11)
N27=t(n7, n0, n5)
N28=vcc(n11)
N29=gnd(n12)
N30=gnd(n13)
N31=gnd(n14)
N32=gnd(n15)
N33=gnd(n16)
N34=gnd(n17)
N35=gnd(n18)
N36=gnd(n19)
N37=gnd(n20)
N38=gnd(n21)
N39=gnd(n22)
N40=gnd(n23)
N41=gnd(n24)
N42=gnd(n25)
N43=gnd(n26)
N44=gnd(n27)
N45=vcc(n28)
N46=vcc(n29)
N47=vcc(n30)
N48=vcc(n31)
N49=vcc(n32)
N50=vcc(n33)
N51=vcc(n34)
N52=vcc(n35)
N53=vcc(n36)
N54=vcc(n37)
N55=t(aul_alul_w, n7, n38)
N56=gnd(n38)
n0~precharge
n1~latched_nano.64
n2~latched_nano.63
n3~latched_nano.47
n4~latched_nano.46
n5~latched_nano.48
]], megabus_control)

move(nl, 0, 0, [[
N16 1750 2979 waul_alul_w,
N45 1751 2983,
N55 1756 2979 en38,
N56 1755 2975,
N27 1785 2980 nn7,

N18 1750 2964 waul_a_w,
N47 1751 2968,
N1  1756 2964 en13,
N30 1755 2960,
N2  1766 2964 en14,
N31 1765 2960,

N20 1750 2950 waul_d_w,
N49 1751 2954,
N4  1756 2950 en16,
N33 1755 2946,
N5  1766 2950 en17,
N34 1765 2946,

N21 1750 2911 wpcl_aul_w,
N50 1751 2915,
N6  1756 2911 en18,
N35 1755 2907,
N7  1766 2911 en19,
N36 1765 2907,

N23 1750 2870 waobl_aul_w,
N52 1751 2874,
N10 1756 2870 en22,
N39 1755 2866,
N9  1766 2870 en21,
N38 1765 2866,

N25 1750 2856 waobl_a_w,
N54 1751 2860,
N13 1756 2856 en25,
N42 1755 2852,
N12 1766 2856 en24,
N41 1765 2852,

N26 1750 2840 waobl_d_w,
N28 1751 2844,
N14 1756 2840 en26,
N43 1755 2836,
N15 1766 2840 en27,
N44 1765 2836,


N17 1840 2964 wn6,
N46 1841 2968,
N0  1846 2964 en12,
N29 1845 2960,

N19 1840 2950 wn8,
N48 1841 2954,
N3  1846 2950 en15,
N32 1845 2946,

N22 1840 2870 wn9,
N51 1841 2874,
N8  1846 2870 en20,
N37 1845 2866,

N24 1840 2890 wn10,
N53 1841 2894,
N11 1846 2890 en23,
N40 1845 2886,
]])

route(nl, 0, 0, [[
aul_alul_w 1753 2983 1753 2975,
n0 1781 2984,
aul_a_w 1753 2968 1753 2960,
aul_d_w 1753 2954 1753 2946,
pcl_aul_w 1753 2915 1753 2907,
aobl_aul_w 1753 2874 1753 2866,
aobl_a_w 1753 2860 1753 2852,
aobl_d_w 1753 2844 1753 2836,
n6 1843 2968 1843 2960 1760 2917 1772 2917 1772 2964,
n9 1843 2874 1843 2866,
n8 1843 2954 1843 2946,
n10 1843 2894 1843 2886 1760 2890,
n4 1852 2964 1852 2943 1760 2943,
n3 1850 2971 1760 2971,
]])


megabus.aobl_0_test:route(1640, 2874, 1640, 2929)
megabus.aobl_aul_w:route(1640, 2858, 1640, 2868)
megabus.aobl_d_w:route(1640, 2854, 1640, 2838)

local n = nodes_rect(1640, 2676, 1830, 2566)
local n1 = nodes_rect(1756, 2646, 1757, 2644)[1]
local nl1 = match(n, "A=d(v,o,o) B=t(o,i2,g) V=vcc(v) G=gnd(g)", { A = n1 })
move(nl1, 1630, 2645, [[
A 55 -6 wo,
V 56 -2,
B 61 -6 eg,
G 60 -10,
]])
route(nl1, 1630, 2645, [[
o 47 -1 47 -13 47 -6 58 -2 58 -10,
]])

r18_driver(n, 1630, 2645, megabus.ibuf_d, nl1.o, nil)
r18_driver(n, 1630, 2621, megabus.ibuf_a, nil, nl1.o)

local n1 = nodes_rect(1785, 2660, 1820, 2635)
local nl = match(n1, "A=d(v,o,o) B=t(o,i,g) V=vcc(v) G=gnd(g)")
move(nl, 1710, 2650, "A 0 0 wo, B 6 0 eg, V 1 4, G 5 -4")
route(nl, 1710, 2650, "o 3 4 3 -4")
nl.i:route(1926, 2650, 1926, 2968, 2174, 2968, 2174, 3163)

local n1 = nodes_rect(1785, 2630, 1820, 2605)
local nl = match(n1, "A=d(v,o,o) B=t(o,i,g) V=vcc(v) G=gnd(g)")
move(nl, 1710, 2626, "A 0 0 wo, B 6 0 eg, V 1 4, G 5 -4")
route(nl, 1710, 2626, "o 3 4 3 -4")
nl.i:route(1928, 2626, 1928, 2966, 2176, 2966, 2176, 3152)

megabus_control.ib_to_ibuf = drive_1_2e(n, 1670, 2609, megabus.ib_to_ibuf)
megabus_control.ib_to_ibuf:route(1932, 2603, 1932, 2962, 2180, 2962, 2180, 3130)

local i = pp_direct_drive(n, 1710, 2584, megabus.ibuf_to_b)
i:route(1716, 2569, 1930, 2569, 1930, 2964, 2178, 2964, 2178, 3141)

megabus.aobl_r:route(1640, 2775, 1640, 2786)
megabus.eu_mvm_w:route(1640, 2759, 1640, 2769)
megabus.ibuf_d:route(1620, 2644, 1620, 2649)
megabus.ibuf_a:route(1620, 2632, 1620, 2625)
megabus.ibuf_to_ib:route(1640, 2570, 1640, 2580)
megabus.eu_mvm_r0:route(2067, 3434, 2067, 3396, 1967, 3396, 1967, 3256, 1934, 3256, 1934, 2681)
megabus.eu_mvm_r1:route(1969, 3394, 1969, 3254, 1936, 3254, 1936, 2679, 1608, 2679, 1608, 2673)
megabus.eu_mvm_r2:route(1971, 3354, 1971, 3252, 1938, 3252, 1938, 2677, 1610, 2677, 1610, 2665)
megabus.eu_mvm_r3:route(1973, 3314, 1973, 3250, 1940, 3250, 1940, 2675, 1612, 2675, 1612, 2657)

named_net("clk_phase_mb_write"):route(1641, 3317, 1641, 3295, 1641, 3403, 1641, 3334, 1666, 3560, 1692, 3548, 1692, 3480, 1666, 3480, 1692, 3494, 1692, 3521, 1692, 3577, 1692, 3606, 1641, 3087, 1641, 2990, 1666, 2990, 1666, 2962, 1666, 2945, 1666, 2920, 1666, 2896, 1666, 2868, 1666, 2838, 1666, 2827, 1666, 2798, 1666, 2769, 1666, 2735, 1639, 2735, 1692, 2990, 1692, 2950, 1692, 2972, 1692, 2930, 1692, 2911, 1692, 2884, 1692, 2856, 1692, 3006, 1747, 3006, 1692, 2844, 1692, 2815, 1692, 2786, 1639, 2144, 1639, 2029, 1696, 2029, 1696, 1664, 1696, 1637, 1696, 1650, 1664, 1650, 1754, 1650, 1754, 1586, 1754, 1561, 1754, 1536, 1696, 1530, 1664, 1530, 1696, 1504, 1696, 1477, 1696, 1450, 1696, 1391, 1696, 1364, 1696, 1334, 1664, 1334, 1664, 1132, 1690, 1132, 1690, 1142, 1664, 1145, 1664, 748, 1684, 748, 1664, 612, 1872, 612, 1696, 1600, 1696, 1540, 1754, 1620, 1696, 1570, 4429, 4188, 2426, 4188, 2130, 3006, 2130, 3814, 2130, 3580, 2130, 3330, 2426, 3814, 2700, 4188, 3000, 4188, 3300, 4188, 3600, 4188, 3900, 4188, 4200, 4188)
named_net("clk_phase_mb_read"):route(1639, 3425, 1701, 3472, 2290, 3472, 2046, 3472, 2989, 4182, 2412, 4182, 2412, 3472, 2412, 3900, 1639, 2988, 1694, 2988, 1694, 2979, 1694, 2757, 1694, 2603, 1694, 2737, 1641, 2737, 1641, 2649, 1641, 2627, 1641, 2611, 1694, 2611, 1641, 2496, 1641, 2470, 1641, 2166, 1641, 2051, 1666, 2051, 1666, 1980, 1668, 1980, 1668, 1703, 1668, 1413, 1668, 1376, 4176, 4182, 1668, 1330, 1650, 1330, 1690, 1330, 1650, 838, 1690, 838, 1650, 1070, 1650, 1295, 1650, 1248, 1690, 794, 1721, 794, 1721, 363)

named_net("mbus_enable_h_ab"):route(1690, 3548, 1690, 3641, 1690, 3668, 1690, 3695, 1690, 3722, 1690, 3749, 1690, 3776, 1690, 3803, 1690, 3830, 1690, 3857, 1690, 3884, 1690, 3911, 1690, 3938, 1690, 3965, 1690, 3992, 1690, 4019, 1690, 4046, 1690, 4073, 1690, 4100, 1690, 3414)

named_net("mbus_enable_ld_db"):route(1664, 2155, 1664, 2458, 1664, 2673, 1753, 2673, 1753, 2458)
named_net("mbus_enable_ld_ab"):route(1690, 1960, 1694, 1960, 1694, 2040, 1694, 2200, 1690, 2200, 1690, 2460, 1755, 2460, 1755, 2700, 1755, 2820, 1690, 2820)


for i=0,15 do
   named_net(string.format("mbus_ib0.%d", i)):route(2340-2*i, 2530+2*i, 2340-2*i, 2839-11*i)
end

local n = nodes_rect(1640, 2500, 1930, 2430)

local n1 = nodes_rect(1851, 2443, 1853, 2441)[1]
local nl1 = match(n, "A=d(v,o,o) B=t(o,i2,g) V=vcc(v) G=gnd(g)", { A = n1 })
move(nl1, 1630, 2490, [[
A 55 -6 wo,
V 56 -2,
B 61 -6 eg,
G 60 -10,
]])
route(nl1, 1630, 2490, [[
o 47 -1 47 -6 47 -13 58 -2 58 -10,
]])

megabus.r0l_dbc:route(1624, 2494, 1624, 2467)
megabus.r0l_abc:route(1626, 2470, 1626, 2455)

r18_driver(n, 1630, 2490, megabus.r0l_dbc, nl1.o, nil)
r18_driver(n, 1630, 2466, megabus.r0l_abc, nil, nl1.o)



local n = nodes_rect(1760, 2465, 1770, 2455)
n = merge(n, nodes_rect(1900, 2455, 1920, 2435))
local nl = match(n, [[
A=t(b, a, g)
B=t(c, a, f)
C=t(e, a, d)
a~precharge
b~latched_nano.38
c~latched_nano.37
d~latched_nano.36
]])
move(nl, 0, 0, [[
B 1785 2496 nf,
A 1785 2485 ng,
C 1785 2472 ne,
]])
route(nl, 0, 0, [[
g 1695 2501 1695 2465,
a 1781 2500 1781 2489 1781 2476,
]])



local nl = rw_driver(nodes_rect(1635, 2195, 1730, 2135), 1670, 2155, 115)

megabus.ld_d_connect:route(1644, 2124, 1644, 2121)
megabus.ld_a_connect:route(1644, 2100, 1644, 2103)

local n = nodes_rect(1630, 2135, 1760, 2060)
pp_bi_inverted_drive(n, 1670, 2128, megabus.ld_d_connect)
pp_bi_inverted_drive(n, 1670, 2104, megabus.ld_a_connect)

local nl = rw_driver(nodes_rect(1630, 2060, 1720, 2010), 1670, 2040, 115)

local n = nodes_rect(1705, 2020, 1765, 1965)
drive_1_1id(n, 1670, 1974, megabus.d_sense_amp_keep_8_15)

megabus.d_clear_8_15:route(1622, 1996, 1622, 1961)
local n = nodes_rect(1640, 2005, 1690, 1980)
local i = pp_bi_inverted_drive(n, 1670, 2000, megabus.d_clear_8_15)
i:route(1690, 1964)

megabus.y1710:route(1622, 1703, 1622, 1710)
megabus.y1650:route(1705, 1682, 1694, 1682, 1694, 1690, 1622, 1690, 1622, 1650)
megabus.y1580:route(1624, 1676, 1624, 1581)
megabus.dbin_to_dbd:route(1626, 1664, 1626, 1548)
megabus.dbin_to_abd:route(1628, 1637, 1628, 1536)
megabus.dbinl_read:route(1630, 1622, 1630, 1529)
megabus.dbinh_read:route(1632, 1610, 1632, 1527)
megabus.copy_ext_bytes:route(1634, 1585, 1634, 1508)
megabus.dbouth_write:route(1622, 1560, 1622, 1501)
megabus.dboutl_write:route(1624, 1535, 1624, 1499)
megabus.y1450:route(1626, 1516, 1626, 1450)
megabus.y1427:route(1628, 1504, 1628, 1427)
megabus.y1425:route(1630, 1489, 1630, 1425)

local n = nodes_rect(1630, 1720, 1790, 1200)
drive_0_2e(n, 1670, 1697, megabus.y1710)
ifeedback(n, 1700, 1685, megabus.y1650)
drive_0_2e(n, 1670, 1670, megabus.y1580)
drive_1_1id2(n, 1670, 1670, megabus.dbin_to_dbd)
drive_1_1id2(n, 1670, 1643, megabus.dbin_to_abd)
drive_0_2id(n, 1670, 1616, megabus.dbinl_read)
drive_1_2id(n, 1670, 1616, megabus.dbinh_read)
megabus_control.copy_ext_bytes = drive_latched(n, 1700, 1575, megabus.copy_ext_bytes)
megabus_control.dbouth_write = drive_i_latched(n, 1700, 1550, megabus.dbouth_write)
megabus_control.dboutl_write = drive_i_latched(n, 1700, 1525, megabus.dboutl_write)
drive_0_2e(n, 1670, 1510, megabus.y1450)
drive_1_2e(n, 1670, 1510, megabus.y1427)
drive_0_2e(n, 1670, 1483, megabus.y1425)

local n1 = nodes_rect(1740, 1575, 1785, 1521)
local nl = match(n, [[
A=t(copy_ext_bytes, a, b)
B=t(dbouth_write, a, c)
C=t(dboutl_write, a, d)
]], megabus_control)
move(nl, 0, 0, [[
A 1750 1582 ncopy_ext_bytes,
B 1750 1557 ndbouth_write,
C 1750 1532 ndboutl_write,
]])



megabus.y1406:route(1622, 1477, 1622, 1406)
megabus_control.y1406 = drive_1_1id2(n, 1670, 1483, megabus.y1406)
local t = nodes_rect(1768, 1455, 1770, 1453)[1]
t:move(1785, 1473, "n", megabus_control.y1406)
t:gate():route(1781, 1477)

megabus.y1418:route(1632, 1450, 1632, 1418)
megabus_control.y1418 = drive_1_1id2(n, 1670, 1456, megabus.y1418)
local t = nodes_rect(1768, 1440, 1770, 1438)[1]
t:move(1785, 1446, "n", megabus_control.y1418)
t:gate():route(1781, 1450)

local nl = rw_driver(n, 1670, 1402, 0, megabus.y1402)

megabus.y1367:route(1622, 1376, 1622, 1367)
megabus.y1344:route(1622, 1364, 1622, 1344)


drive_0_2id(n, 1670, 1370, megabus.y1367)
drive_1_1id(n, 1670, 1370, megabus.y1344)
ifeedback(n, 1710, 1344, megabus.y1335)

nl.c:set_name("euc.shiftlatch_to_mbus_dbd")



local nl = match(n, "A=t(a,b,c)", { a=megabus.y1335 })
nl.A:move(1714, 1334, "w", nl.c)
nl.c:route(1730, 1330)
megabus.y1335:route(1650, 1335, 1650, 1338)
ifeedback(n, 1725, 1333, nl.c)

drive_0_2e(n, 1670, 1310, megabus.y1330)
megabus.y1330:route(1646, 1330, 1646, 1316)

megabus_control.y1286 = drive_1_1id(n, 1670, 1310, megabus.y1286)
local t = nodes_rect(1761, 1250, 1763, 1148)[1]
t:move(1785, 1305, "n", megabus_control.y1286)
t:gate():route(1781, 1309)

ifeedback(n, 1710, 1284, megabus.y1328)
pp_inverted_drive(n, 1690, 1292, megabus.y1326)
f_inverted(n, 1730, 1271, megabus.y1271)
megabus.y1328:route(1642, 1328, 1642, 1277, 1715, 1277)
megabus.y1326:route(1644, 1326, 1644, 1288)

local n = nodes_rect(1620, 1190, 1800, 780)
f_inverted(n, 1670, 1234, megabus.y1234)
pp_inverted_drive(n, 1670, 1171, megabus.y1167)
pp_bi_inverted_drive(n, 1670, 1150, megabus.y1097)
inverted(n, 1672, 1086, megabus.y1086)

pp_direct_drive(n, 1730, 1067, megabus.y1063)
pp_direct_drive(n, 1700, 1056, megabus.y1059)

megabus_control.y1027 = pp_inverted_drive(n, 1670, 1045, megabus.y1027)
local t = nodes_rect(1768, 1061, 1770, 1059)[1]
t:move(1785, 1040, "n", megabus_control.y1027)
t:gate():route(1781, 1044)
megabus_control.y1027:route(1681, 1039, 1681, 1030, 1674, 1030, 1734, 1039)

megabus_control.y1000 = pp_inverted_drive(n, 1730, 1032, megabus.y1000)
local t = nodes_rect(1773, 1039, 1775, 1037)[1]
t:move(1785, 1018, "n", megabus_control.y1000)
t:gate():route(1781, 1022)
megabus_control.y1000:route(1734, 1017)

megabus_control.y993 = pp_inverted_drive(n, 1700, 1021, megabus.y993)
local t = nodes_rect(1773, 1029, 1775, 1027)[1]
t:move(1785, 1007, "n", megabus_control.y993)
t:gate():route(1781, 1011)
megabus_control.y993:route(1704, 1006)

pp_inverted_drive(n, 1670, 1010, megabus.y986)
pp_bi_inverted_drive(n, 1690, 995, megabus.y968)
drive_0_2e(n, 1670, 965, megabus.y957)
pp_direct_drive(n, 1670, 958, megabus.y950)
pp_direct_drive(n, 1730, 947, megabus.y943)

megabus_control.y936 = pp_inverted_drive(n, 1700, 936, megabus.y936)
local t = nodes_rect(1774, 959, 1776, 957)[1]
t:move(1785, 922, "n", megabus_control.y936)
t:gate():route(1781, 926)
megabus_control.y936:route(1704, 921)

pp_inverted_drive(n, 1670, 926, megabus.y910):route(1674, 911, 1682, 911, 1682, 919, 1725, 919, 1725, 923, 1732, 923, 1742, 923, 1742, 917, 1742, 911)
pp_inverted_drive(n, 1730, 915, megabus.y903)

megabus_control.y896 = pp_inverted_drive(n, 1700, 904, megabus.y896)
local t = nodes_rect(1769, 911, 1771, 909)[1]
t:move(1785, 890, "n", megabus_control.y896)
t:gate():route(1781, 894)
megabus_control.y896:route(1704, 889)

megabus_control.y885 = ifeedback(n, 1670, 880, megabus.y885)

megabus_control.y875 = pp_inverted_drive(n, 1730, 879, megabus.y875)
local t = nodes_rect(1769, 879, 1771, 877)[1]
t:move(1785, 865, "n", megabus_control.y875)
t:gate():route(1781, 869)
megabus_control.y875:route(1734, 864)

megabus_control.y870 = pp_inverted_drive(n, 1700, 868, megabus.y870)
megabus_control.y863 = pp_direct_drive(n, 1670, 857, megabus.y863)

megabus_control.dbd_to_alu_w = drive_1_1id2(n, 1670, 837, megabus.dbd_to_alu_w)
local t = nodes_rect(1768, 827, 1770, 825)[1]
t:move(1785, 827, "n", megabus_control.dbd_to_alu_w)
t:gate():route(1781, 831)

megabus_control.abd_to_alu_w = drive_1_1id2(n, 1670, 810, megabus.abd_to_alu_w)
local t = nodes_rect(1769, 812, 1771, 810)[1]
t:move(1785, 800, "n", megabus_control.abd_to_alu_w)
t:gate():route(1781, 804)




local n = nodes_rect(1645, 770, 1695, 745)
local nl = match(n, [[
A=t(b, c, f)
B=t(e, c, g)
C=d(e, e, h)
D=t(b, d, a)
E=t(d, i, e)
F=gnd(f)
G=gnd(g)
H=vcc(h)
I=vcc(i)
]])

move(nl, 0, 0, [[
D 1685 771 eb,
A 1685 763 ef,
F 1684 759,
E 1693 772 nd,
I 1693 776,
C 1701 771 we,
H 1702 775,
B 1701 763 wg,
G 1702 759,
]])


local n = nodes_rect(1650, 745, 1695, 705)
local nl = match(n, [[
A=t(f, d, c)
B=t(d, b, g)
C=d(d, d, h)
D=t(c, e, a)
E=t(e, i, b)
F=gnd(f)
G=gnd(g)
H=vcc(h)
I=vcc(i)
]])

move(nl, 0, 0, [[
D 1685 736 ec,
A 1685 728 ef,
F 1684 724,
E 1693 737 ne,
I 1693 741,
C 1703 736 wd,
H 1704 740,
B 1703 728 wg,
G 1704 724,
]])

route(nl, 0, 0, [[
d 1697 728,
]])


local n = nodes_rect(1710, 760, 1765, 675)
local nl = match(n, [[
A=t(e, g, j)
B=t(k, h, g)
C=t(l, f, i)
D=d(e, e, m)
E=d(g, g, n)
F=t(h, a, o)
G=d(i, i, p)
H=t(d, c, f)
I=t(e, e, h)
J=t(h, b, i)
K=gnd(j)
L=gnd(k)
M=gnd(l)
N=vcc(m)
O=vcc(n)
P=vcc(o)
Q=vcc(p)
]])

latch(n, 1730, 738)

move(nl, 0, 0, [[
H 1785 737 nf,
C 1776 736 el,
M 1775 732,
G 1770 736 wi,
Q 1771 740,
F 1725 748 wh,
P 1726 752,
J 1725 740 wi,
]])

route(nl, 0, 0, [[
c 1781 741,
i 1773 732 1773 740,
e 1697 756,
]])


local n = nodes_rect(1750, 2450, 1940, 1735)
n = merge(n, nodes_rect(1720, 2020, 1750, 1990))
n = merge(n, nodes_rect(1720, 2130, 1755, 2065))

local nl = match(n, [[
N0=t(n141, n17, n3)
N1=t(n158, n18, n11)
N2=t(n159, n1, n12)
N3=t(n160, n98, n13)
N4=t(n161, n18, n16)
N5=t(n162, n18, n18)
N6=t(n163, n82, n19)
N7=t(n164, n85, n20)
N8=t(n22, n18, n165)
N9=t(n166, n99, n23)
N10=t(n25, n18, n167)
N11=t(n168, n107, n26)
N12=t(n27, n81, n169)
N13=t(n170, n26, n28)
N14=t(n171, n18, n29)
N15=t(n33, n18, n172)
N16=t(n173, n59, n35)
N17=t(n36, n18, n174)
N18=t(n175, n55, n41)
N19=t(n176, n18, n44)
N20=t(n177, n60, n45)
N21=t(n46, n18, n178)
N22=t(n49, n18, n179)
N23=t(n180, n56, n51)
N24=t(n52, n18, n181)
N25=t(n182, n18, n54)
N26=t(n183, n18, n57)
N27=t(n184, n86, n61)
N28=t(n185, n18, n63)
N29=t(n186, n97, n64)
N30=t(n65, n18, n187)
N31=t(n72, n18, n188)
N32=t(n189, n18, n73)
N33=t(n190, n18, n76)
N34=t(n81, n42, n191)
N35=t(n192, n55, n82)
N36=t(n193, n82, n83)
N37=t(n194, n85, n84)
N38=t(n195, n56, n85)
N39=t(n196, n43, n86)
N40=t(n197, n6, n88)
N41=t(n198, n90, n88)
N42=t(n89, n40, n199)
N43=t(n90, n9, n200)
N44=t(n201, n10, n90)
N45=t(n91, n89, n202)
N46=t(n92, n39, n203)
N47=t(n204, n92, n94)
N48=t(n205, n67, n97)
N49=t(n206, n71, n98)
N50=t(n99, n59, n207)
N51=t(n101, n99, n208)
N52=t(n209, n66, n102)
N53=t(n210, n102, n103)
N54=t(n104, n18, n211)
N55=t(n212, n70, n105)
N56=t(n213, n105, n106)
N57=t(n107, n60, n214)
N58=t(n215, n108, n108)
N59=t(n109, n18, n216)
N60=t(n217, n107, n110)
N61=t(n218, n18, n111)
N62=t(n219, n18, n114)
N63=t(n116, n18, n220)
N64=t(n118, n18, n221)
N65=t(n119, n18, n222)
N66=t(n123, n18, n223)
N67=t(n125, n18, n224)
N68=t(n126, n18, n225)
N69=t(n226, n18, n127)
N70=t(n132, n18, n227)
N71=t(n133, n18, n228)
N72=t(n134, n18, n229)
N73=t(n136, n18, n230)
N74=t(n139, n18, n231)
N75=d(n3, n3, n232)
N76=d(n142, n12, n12)
N77=t(n143, n71, n13)
N78=t(n144, n13, n14)
N79=t(n145, n83, n19)
N80=t(n20, n84, n146)
N81=t(n147, n101, n23)
N82=t(n148, n110, n26)
N83=t(n149, n42, n27)
N84=t(n150, n13, n31)
N85=t(n151, n99, n35)
N86=t(n38, n27, n152)
N87=t(n153, n82, n41)
N88=t(n45, n107, n154)
N89=t(n48, n27, n155)
N90=t(n156, n13, n50)
N91=t(n157, n85, n51)
N92=t(n61, n43, n233)
N93=t(n62, n61, n234)
N94=t(n235, n67, n64)
N95=t(n236, n64, n68)
N96=t(n75, n61, n237)
N97=t(n238, n64, n78)
N98=d(n81, n81, n239)
N99=d(n240, n82, n82)
N100=d(n83, n83, n241)
N101=d(n84, n84, n242)
N102=d(n243, n85, n85)
N103=d(n86, n86, n244)
N104=d(n88, n88, n245)
N105=d(n89, n89, n246)
N106=d(n90, n90, n247)
N107=t(n248, n40, n91)
N108=d(n92, n92, n249)
N109=t(n250, n39, n94)
N110=d(n97, n97, n251)
N111=d(n252, n98, n98)
N112=d(n253, n99, n99)
N113=d(n101, n101, n254)
N114=d(n102, n102, n255)
N115=t(n256, n66, n103)
N116=d(n105, n105, n257)
N117=t(n258, n70, n106)
N118=d(n107, n107, n259)
N119=t(n260, n260, n108)
N120=d(n261, n110, n110)
N121=t(n262, n106, n112)
N122=t(n117, n91, n263)
N123=t(n264, n106, n120)
N124=t(n124, n91, n265)
N125=t(n266, n103, n129)
N126=t(n130, n94, n267)
N127=t(n137, n94, n268)
N128=t(n269, n103, n138)
N129=t(n79, n0, n2)
N130=t(n3, n23, n24)
N131=t(n80, n0, n4)
N132=t(n87, n0, n5)
N133=t(n95, n0, n7)
N134=t(n96, n0, n8)
N135=t(n17, n0, n10)
N136=t(n21, n19, n11)
N137=t(n14, n12, n15)
N138=t(n15, n20, n21)
N139=t(n16, n12, n30)
N140=t(n108, n108, n18)
N141=t(n30, n1, n22)
N142=t(n24, n27, n28)
N143=t(n25, n1, n34)
N144=t(n37, n41, n29)
N145=t(n30, n23, n32)
N146=t(n31, n20, n37)
N147=t(n32, n35, n33)
N148=t(n32, n26, n38)
N149=t(n34, n19, n37)
N150=t(n36, n23, n47)
N151=t(n44, n19, n53)
N152=t(n53, n41, n46)
N153=t(n47, n45, n48)
N154=t(n47, n35, n49)
N155=t(n50, n51, n53)
N156=t(n52, n23, n58)
N157=t(n54, n19, n69)
N158=t(n57, n41, n69)
N159=t(n58, n26, n62)
N160=t(n58, n35, n63)
N161=t(n65, n23, n74)
N162=t(n68, n20, n69)
N163=t(n72, n19, n77)
N164=t(n77, n41, n73)
N165=t(n74, n45, n75)
N166=t(n74, n35, n76)
N167=t(n77, n51, n78)
N168=t(n93, n0, n88)
N169=t(n90, n0, n100)
N170=t(n115, n23, n104)
N171=t(n113, n19, n109)
N172=t(n113, n41, n111)
N173=t(n112, n20, n113)
N174=t(n115, n35, n114)
N175=t(n115, n26, n117)
N176=t(n121, n23, n116)
N177=t(n118, n19, n122)
N178=t(n122, n41, n119)
N179=t(n120, n51, n122)
N180=t(n121, n35, n123)
N181=t(n121, n45, n124)
N182=t(n128, n23, n125)
N183=t(n131, n19, n126)
N184=t(n131, n41, n127)
N185=t(n128, n26, n130)
N186=t(n128, n35, n132)
N187=t(n129, n20, n131)
N188=t(n133, n23, n135)
N189=t(n134, n19, n140)
N190=t(n135, n45, n137)
N191=t(n135, n35, n139)
N192=t(n140, n41, n136)
N193=t(n138, n51, n140)
N194=gnd(n141)
N195=vcc(n142)
N196=vcc(n143)
N197=vcc(n144)
N198=vcc(n145)
N199=vcc(n146)
N200=vcc(n147)
N201=vcc(n148)
N202=vcc(n149)
N203=vcc(n150)
N204=vcc(n151)
N205=vcc(n152)
N206=vcc(n153)
N207=vcc(n154)
N208=vcc(n155)
N209=vcc(n156)
N210=vcc(n157)
N211=gnd(n158)
N212=gnd(n159)
N213=gnd(n160)
N214=gnd(n161)
N215=gnd(n162)
N216=gnd(n163)
N217=gnd(n164)
N218=gnd(n165)
N219=gnd(n166)
N220=gnd(n167)
N221=gnd(n168)
N222=gnd(n169)
N223=gnd(n170)
N224=gnd(n171)
N225=gnd(n172)
N226=gnd(n173)
N227=gnd(n174)
N228=gnd(n175)
N229=gnd(n176)
N230=gnd(n177)
N231=gnd(n178)
N232=gnd(n179)
N233=gnd(n180)
N234=gnd(n181)
N235=gnd(n182)
N236=gnd(n183)
N237=gnd(n184)
N238=gnd(n185)
N239=gnd(n186)
N240=gnd(n187)
N241=gnd(n188)
N242=gnd(n189)
N243=gnd(n190)
N244=gnd(n191)
N245=gnd(n192)
N246=gnd(n193)
N247=gnd(n194)
N248=gnd(n195)
N249=gnd(n196)
N250=gnd(n197)
N251=gnd(n198)
N252=gnd(n199)
N253=gnd(n200)
N254=gnd(n201)
N255=gnd(n202)
N256=gnd(n203)
N257=gnd(n204)
N258=gnd(n205)
N259=gnd(n206)
N260=gnd(n207)
N261=gnd(n208)
N262=gnd(n209)
N263=gnd(n210)
N264=gnd(n211)
N265=gnd(n212)
N266=gnd(n213)
N267=gnd(n214)
N268=gnd(n215)
N269=gnd(n216)
N270=gnd(n217)
N271=gnd(n218)
N272=gnd(n219)
N273=gnd(n220)
N274=gnd(n221)
N275=gnd(n222)
N276=gnd(n223)
N277=gnd(n224)
N278=gnd(n225)
N279=gnd(n226)
N280=gnd(n227)
N281=gnd(n228)
N282=gnd(n229)
N283=gnd(n230)
N284=gnd(n231)
N285=vcc(n232)
N286=vcc(n233)
N287=vcc(n234)
N288=vcc(n235)
N289=vcc(n236)
N290=vcc(n237)
N291=vcc(n238)
N292=vcc(n239)
N293=vcc(n240)
N294=vcc(n241)
N295=vcc(n242)
N296=vcc(n243)
N297=vcc(n244)
N298=vcc(n245)
N299=vcc(n246)
N300=vcc(n247)
N301=vcc(n248)
N302=vcc(n249)
N303=vcc(n250)
N304=vcc(n251)
N305=vcc(n252)
N306=vcc(n253)
N307=vcc(n254)
N308=vcc(n255)
N309=vcc(n256)
N310=vcc(n257)
N311=vcc(n258)
N312=vcc(n259)
N313=vcc(n260)
N314=vcc(n261)
N315=vcc(n262)
N316=vcc(n263)
N317=vcc(n264)
N318=vcc(n265)
N319=vcc(n266)
N320=vcc(n267)
N321=vcc(n268)
N322=vcc(n269)
n0~precharge
n2~latched_nano.35
n4~latched_nano.34
n5~latched_nano.33
n6~latched_nano.32
n7~latched_nano.31
n8~latched_nano.30
n9~latched_nano.29
n13~mbus_regd_l_id.5'1
n18~osc2a
n19~nmbus_regd_l_id.0'1
n20~nmbus_regd_l_id.1'1
n23~mbus_rega_l_id.4'1
n26~mbus_rega_l_id.2'1
n27~mbus_rega_l_id.0'1
n35~nmbus_rega_l_id.4'1
n39~mbus_rega_d_id.1'0
n40~mbus_rega_d_id.0'0
n41~mbus_regd_l_id.0'1
n42~mbus_rega_l_id.0'0
n43~mbus_rega_l_id.1'0
n45~nmbus_rega_l_id.2'1
n51~mbus_regd_l_id.1'1
n55~mbus_regd_l_id.0'0
n56~mbus_regd_l_id.1'0
n59~mbus_rega_l_id.4'0
n60~mbus_rega_l_id.2'0
n61~mbus_rega_l_id.1'1
n64~mbus_regd_l_id.4'1
n66~mbus_rega_l_id.a'0
n67~mbus_regd_l_id.4'0
n70~mbus_rega_l_id.b'0
n71~mbus_regd_l_id.5'0
n91~mbus_rega_d_id.0'1
n94~mbus_rega_d_id.1'1
n108~osc2b
]])

move(nl, 0, 0, [[
N76  1832 2459 wn12,
N195 1833 2463,
N2   1838 2459 en159,
N212 1837 2455,

N205 1751 2437,
N86  1755 2436 sn152,
N148 1777 2436 sn38,
N145 1821 2436 sn32,
N139 1832 2438 wn30,
N4   1855 2438 wn161,
N214 1856 2434,

N197 1751 2423,
N78  1755 2422 sn144,
N137 1766 2422 sn14,
N138 1777 2422 sn15,
N136 1839 2424 wn21,
N1   1855 2424 wn158,
N211 1856 2420,

N141 1846 2411 wn30,
N8   1855 2411 wn165,
N218 1856 2407,

N203 1751 2396,
N84  1755 2395 sn150,
N146 1777 2395 sn31,
N149 1810 2395 sn37,
N143 1846 2397 wn34,
N10  1855 2397 wn167,
N220 1856 2393,

N147 1832 2384 wn32,
N15  1855 2384 wn172,
N225 1856 2380,

N144 1846 2370 wn37,
N14  1855 2370 wn171,
N224 1856 2366,

N208 1751 2356,
N89  1755 2355 sn155,
N153 1788 2355 sn48,
N150 1825 2357 wn47,
N17  1855 2357 wn174,
N227 1856 2353,

N209 1751 2342,
N90  1755 2341 sn156,
N155 1788 2341 sn50,
N151 1839 2343 wn53,
N19  1855 2343 wn176,
N229 1856 2339,

N154 1832 2330 wn47,
N22  1855 2330 wn179,
N232 1856 2326,

N152 1846 2316 wn53,
N21  1855 2316 wn178,
N231 1856 2312,

N287 1762 2302,
N93  1766 2301 sn234,
N159 1777 2301 sn62,
N156 1825 2303 wn58,
N24  1855 2303 wn181,
N234 1856 2299,

N289 1762 2288,
N95  1766 2287 sn236,
N162 1777 2287 sn68,
N157 1839 2289 wn69,
N25  1855 2289 wn182,
N235 1856 2285,

N160 1832 2276 wn58,
N28  1855 2276 wn185,
N238 1856 2272,

N158 1846 2262 wn69,
N26  1855 2262 wn183,
N236 1856 2258,

N290 1762 2248,
N96  1766 2247 sn237,
N165 1777 2247 sn75,
N161 1825 2249 wn74,
N30  1855 2249 wn187,
N240 1856 2245,

N291 1762 2234,
N97  1766 2233 sn238,
N167 1777 2233 sn78,
N163 1839 2235 wn77,
N31  1855 2235 wn188,
N241 1856 2231,

N166 1832 2222 wn74,
N33  1855 2222 wn190,
N243 1856 2218,

N164 1846 2208 wn77,
N32  1855 2208 wn189,
N242 1856 2204,

N285 1876 2448,
N75  1875 2444 wn3,
N0   1879 2436 en141,
N194 1878 2432,
N130 1875 2436 wn24,
N142 1875 2428 wn28,
N13  1875 2420 wn170,
N223 1876 2416,

N135 1900 2437 nn17,


N119 1868 2228 wn108,
N313 1869 2232,
N58  1868 2220 wn215,
N268 1869 2216,
N140 1863 2216 wn18,
N5   1863 2208 wn162,
N215 1864 2204,


N316 1751 1943,
N122 1755 1942 sn263,
N175 1777 1942 sn117,
N170 1825 1944 wn115,
N54  1855 1944 wn211,
N264 1856 1940,

N315 1751 1929,
N121 1755 1928 sn262,
N173 1777 1928 sn112,
N171 1839 1930 wn113,
N59  1855 1930 wn216,
N269 1856 1926,

N174 1832 1917 wn115,
N62  1855 1917 wn219,
N272 1856 1913,

N172 1846 1903 wn113,
N61  1855 1903 wn218,
N271 1856 1899,

N318 1751 1889,
N124 1755 1888 sn265,
N181 1788 1888 sn124,
N176 1825 1890 wn121,
N63  1855 1890 wn220,
N273 1856 1886,

N317 1751 1875,
N123 1755 1874 sn264,
N179 1788 1874 sn120,
N177 1839 1876 wn122,
N64  1855 1876 wn221,
N274 1856 1872,

N180 1832 1863 wn121,
N66  1855 1863 wn223,
N276 1856 1859,

N178 1846 1849 wn122,
N65  1855 1849 wn222,
N275 1856 1845,


N320 1762 1835,
N126 1766 1834 sn267,
N185 1777 1834 sn130,
N182 1825 1836 wn128,
N67  1855 1836 wn224,
N277 1856 1832,

N319 1762 1821,
N125 1766 1820 sn266,
N187 1777 1820 sn129,
N183 1839 1822 wn131,
N68  1855 1822 wn225,
N278 1856 1818,

N186 1832 1809 wn128,
N70  1855 1809 wn227,
N280 1856 1805,

N184 1846 1795 wn131,
N69  1855 1795 wn226,
N279 1856 1791,

N321 1762 1781,
N127 1766 1780 sn268,
N190 1788 1780 sn137,
N188 1825 1782 wn135,
N71  1855 1782 wn228,
N281 1856 1778,

N322 1762 1767,
N128 1766 1766 sn269,
N193 1788 1766 sn138,
N189 1839 1768 wn140,
N72  1855 1768 wn229,
N282 1856 1764,

N191 1832 1755 wn135,
N74  1855 1755 wn231,
N284 1856 1751,

N192 1846 1741 wn140,
N73  1855 1741 wn230,
N283 1856 1737,

N132 1900 2121 nn87,
N168 1900 2097 nn93,
N169 1900 1969 nn100,

N104 1910 2096 wn88,
N298 1911 2100,
N41  1910 2088 wn198,
N251 1911 2084,
N40  1914 2088 en197,
N250 1913 2084,

N106 1910 1968 wn90,
N300 1911 1972,
N44  1910 1960 wn201,
N254 1911 1956,
N43  1914 1960 en200,
N253 1913 1956,
]])

route(nl, 0, 0, [[
n19  1835 2391 1835 2179 1916 2179 1916 2199,
n32  1817 2380,
n37  1806 2366,
n30  1826 2437 1826 2434 1826 2407,
n21  1833 2423 1833 2420,
n34  1840 2396 1840 2393,
n47  1819 2356 1819 2353 1826 2326,
n53  1833 2342 1833 2339 1840 2312,
n58  1819 2302 1819 2299 1826 2272,
n69  1833 2288 1833 2285 1840 2258,
n74  1819 2248 1819 2245 1826 2218,
n77  1833 2234 1833 2231 1840 2204,
n27  1759 2432 1759 2351 1759 2444 1869 2444 1869 2428 1869 2413,
n13  1761 2418 1761 2391 1761 2337 1761 2270 1761 2197 1898 2197 1898 2330 1898 2391,
n61  1770 2297 1770 2243 1770 2195 1900 2195 1900 2369,
n64  1772 2283 1772 2229 1772 2193 1902 2193 1902 2347,
n0   1781 2466 1896 2466 1896 2441 1896 2141 1896 2125 1896 2101 1896 1973 1896 1725 1781 1725,
n12  1770 2418 1828 2440 1770 2440 1835 2463 1835 2455,
n20  1783 2418 1783 2391 1783 2283 1783 2187 1908 2187 1908 2283,
n26  1781 2432 1781 2360 1781 2297 1781 2446 1867 2446 1867 2420 1781 2191 1904 2191 1904 2260 1904 2325,
n45  1792 2351 1792 2243 1792 2189 1906 2189 1906 2305,
n51  1794 2337 1794 2229 1794 2185 1910 2185 1910 2263,
n23  1821 2431 1821 2400 1821 2215 1821 2183 1865 2183 1912 2183 1912 2241 1912 2411 1871 2411 1912 2320 1912 2370 1912 2270 1912 2215,
n18  1851 2201 1859 2201,
n115 1819 1943 1819 1940 1826 1913,
n113 1833 1929 1833 1926 1840 1899,
n121 1819 1889 1819 1886 1826 1859,
n122 1833 1875 1833 1872 1840 1845,
n128 1819 1835 1819 1832 1826 1805,
n131 1833 1821 1833 1818 1840 1791,
n135 1819 1781 1819 1778 1826 1751,
n140 1833 1767 1833 1764 1840 1737,
n91  1759 1938 1759 1884 1759 1956 1904 1956 1904 1938,
n106 1761 1924 1761 1870 1761 1954 1902 1954 1902 1916,
n26  1781 1938 1781 1830,
n20  1783 1924 1783 1816,
n45  1792 1884 1792 1776,
n51  1794 1870 1794 1762,
n94  1770 1830 1770 1776 1770 1952 1900 1952 1900 1894,
n103 1772 1816 1772 1762 1772 1950 1898 1950 1898 1872,
n35  1914 2221 1914 2181 1828 2181,
n41  1918 2179 1918 2177 1842 2177,
]])



local function ddr(n, x, y, o)
   local nl = match(n, [[
A=t(d, c, a)
B=t(e, b, c)
C=t(f, b, a)
D=d(c, c, g)
E=gnd(d)
F=gnd(e)
G=vcc(f)
H=vcc(g)
]], { a=o })
   move(nl, x, y, [[
C  1 12 ea,
G  0 16,
A  1  4 ed,
E  0  0,
D 11 12 wc,
H 12 16,
B 11  4 we,
F 12  0,
]])
end

local function idr(n, x, y, o)
   local nl = match(n, [[
A=t(d, b, a)
B=t(e, b, c)
C=t(f, c, a)
D=d(c, c, g)
E=gnd(d)
F=gnd(e)
G=vcc(f)
H=vcc(g)
]], { a=o })
   move(nl, x, y, [[
C  1 12 ea,
G  0 16,
A  1  4 ed,
E  0  0,
D  9 12 wc,
H 10 16,
B  9  4 we,
F 10  0,
]])
end

ddr(n, 1930, 2405, nl.n27)
ddr(n, 1930, 2383, nl.n13)
ddr(n, 1930, 2361, nl.n61)
ddr(n, 1930, 2339, nl.n64)
idr(n, 1930, 2317, nl.n26)
idr(n, 1930, 2297, nl.n45)
idr(n, 1930, 2275, nl.n20)
idr(n, 1930, 2255, nl.n51)
idr(n, 1930, 2233, nl.n23)
idr(n, 1930, 2213, nl.n35)
idr(n, 1930, 2191, nl.n19)
idr(n, 1930, 2171, nl.n41)

ddr(n, 1930, 1930, nl.n91)
ddr(n, 1930, 1908, nl.n106)
ddr(n, 1930, 1886, nl.n94)
ddr(n, 1930, 1864, nl.n103)

local n = nodes_rect(1990, 2500, 2240, 2050)
local nl = match(n, [[
N0=t(n89, n72, n1)
N1=t(n4, n82, n90)
N2=t(n91, n80, n5)
N3=t(n92, n77, n8)
N4=t(n10, n17, n93)
N5=t(n11, n67, n109)
N6=t(n110, n74, n11)
N7=t(n12, n19, n111)
N8=t(n12, n21, n112)
N9=t(n18, n19, n113)
N10=t(n114, n21, n18)
N11=t(n115, n25, n22)
N12=t(n116, n22, n23)
N13=d(n117, n117, n24)
N14=t(n25, n14, n118)
N15=t(n119, n19, n26)
N16=t(n26, n30, n120)
N17=t(n121, n27, n30)
N18=t(n31, n19, n122)
N19=t(n31, n30, n123)
N20=t(n124, n24, n33)
N21=t(n125, n37, n33)
N22=t(n126, n42, n33)
N23=t(n127, n24, n34)
N24=t(n128, n37, n34)
N25=t(n129, n40, n34)
N26=t(n35, n24, n130)
N27=t(n131, n38, n35)
N28=t(n132, n40, n35)
N29=t(n133, n24, n36)
N30=t(n134, n38, n36)
N31=t(n135, n42, n36)
N32=t(n136, n37, n38)
N33=t(n40, n42, n137)
N34=t(n52, n54, n138)
N35=t(n139, n59, n52)
N36=t(n140, n60, n52)
N37=t(n53, n54, n141)
N38=t(n53, n58, n142)
N39=t(n143, n60, n53)
N40=t(n144, n54, n55)
N41=t(n145, n55, n56)
N42=t(n146, n59, n56)
N43=t(n56, n60, n147)
N44=t(n148, n55, n57)
N45=t(n57, n58, n149)
N46=t(n150, n60, n57)
N47=t(n151, n59, n58)
N48=d(n152, n152, n60)
N49=t(n64, n63, n153)
N50=t(n154, n64, n69)
N51=t(n69, n67, n155)
N52=t(n70, n64, n156)
N53=t(n157, n67, n70)
N54=t(n158, n72, n73)
N55=t(n75, n9, n159)
N56=t(n76, n25, n160)
N57=t(n161, n67, n78)
N58=t(n78, n74, n162)
N59=t(n79, n77, n163)
N60=t(n164, n80, n81)
N61=t(n83, n82, n165)
N62=t(n166, n75, n85)
N63=t(n1, n73, n167)
N64=t(n168, n83, n4)
N65=t(n5, n81, n169)
N66=t(n8, n79, n170)
N67=d(n10, n10, n171)
N68=t(n172, n78, n11)
N69=t(n12, n18, n173)
N70=d(n94, n18, n18)
N71=d(n22, n22, n95)
N72=t(n96, n19, n24)
N73=t(n24, n21, n97)
N74=t(n24, n27, n98)
N75=d(n99, n25, n25)
N76=d(n26, n26, n100)
N77=d(n30, n30, n101)
N78=t(n102, n26, n31)
N79=d(n103, n33, n33)
N80=d(n104, n34, n34)
N81=d(n105, n35, n35)
N82=d(n106, n36, n36)
N83=d(n38, n38, n107)
N84=d(n108, n40, n40)
N85=d(n52, n52, n174)
N86=d(n53, n53, n175)
N87=d(n55, n55, n176)
N88=d(n56, n56, n177)
N89=d(n57, n57, n178)
N90=d(n179, n58, n58)
N91=t(n60, n63, n180)
N92=t(n60, n67, n181)
N93=t(n60, n74, n182)
N94=d(n64, n64, n183)
N95=d(n69, n69, n184)
N96=t(n185, n69, n70)
N97=d(n73, n73, n186)
N98=d(n187, n75, n75)
N99=d(n188, n78, n78)
N100=d(n79, n79, n189)
N101=d(n81, n81, n190)
N102=d(n191, n83, n83)
N103=t(n85, n9, n192)
N104=t(n39, n25, n1)
N105=t(n61, n22, n1)
N106=t(n2, n22, n39)
N107=t(n61, n25, n2)
N108=t(n41, n22, n3)
N109=t(n62, n25, n3)
N110=t(n4, n25, n41)
N111=t(n62, n22, n4)
N112=t(n49, n22, n5)
N113=t(n5, n25, n50)
N114=t(n49, n25, n6)
N115=t(n50, n22, n6)
N116=t(n44, n25, n7)
N117=t(n7, n22, n51)
N118=t(n44, n22, n8)
N119=t(n51, n25, n8)
N120=t(n13, n0, n19)
N121=t(n67, n0, n15)
N122=t(n16, n0, n17)
N123=t(n23, n25, n20)
N124=t(n20, n22, n76)
N125=t(n23, n0, n21)
N126=t(n27, n0, n28)
N127=t(n28, n25, n29)
N128=t(n28, n22, n32)
N129=t(n71, n22, n29)
N130=t(n71, n25, n32)
N131=t(n37, n0, n39)
N133=t(n41, n0, n42)
N134=t(n44, n0, n43)
N135=t(n45, n0, n49)
N136=t(n46, n0, n51)
N137=t(n47, n0, n50)
N138=t(n72, n75, n48)
N139=t(n54, n0, n62)
N140=t(n59, n0, n61)
N141=t(n63, n0, n71)
N142=t(n77, n75, n65)
N143=t(n80, n75, n66)
N144=t(n82, n75, n68)
N145=t(n72, n85, n84)
N146=t(n74, n0, n76)
N147=t(n77, n85, n88)
N148=t(n80, n85, n87)
N149=t(n82, n85, n86)
N150=gnd(n89)
N151=gnd(n90)
N152=gnd(n91)
N153=gnd(n92)
N154=gnd(n93)
N155=vcc(n94)
N156=vcc(n95)
N157=vcc(n96)
N158=vcc(n97)
N159=vcc(n98)
N160=vcc(n99)
N161=vcc(n100)
N162=vcc(n101)
N163=vcc(n102)
N164=vcc(n103)
N165=vcc(n104)
N166=vcc(n105)
N167=vcc(n106)
N168=vcc(n107)
N169=vcc(n108)
N170=gnd(n109)
N171=gnd(n110)
N172=gnd(n111)
N173=gnd(n112)
N174=gnd(n113)
N175=gnd(n114)
N176=gnd(n115)
N177=gnd(n116)
N178=gnd(n117)
N179=gnd(n118)
N180=gnd(n119)
N181=gnd(n120)
N182=gnd(n121)
N183=gnd(n122)
N184=gnd(n123)
N185=gnd(n124)
N186=gnd(n125)
N187=gnd(n126)
N188=gnd(n127)
N189=gnd(n128)
N190=gnd(n129)
N191=gnd(n130)
N192=gnd(n131)
N193=gnd(n132)
N194=gnd(n133)
N195=gnd(n134)
N196=gnd(n135)
N197=gnd(n136)
N198=gnd(n137)
N199=gnd(n138)
N200=gnd(n139)
N201=gnd(n140)
N202=gnd(n141)
N203=gnd(n142)
N204=gnd(n143)
N205=gnd(n144)
N206=gnd(n145)
N207=gnd(n146)
N208=gnd(n147)
N209=gnd(n148)
N210=gnd(n149)
N211=gnd(n150)
N212=gnd(n151)
N213=gnd(n152)
N214=gnd(n153)
N215=gnd(n154)
N216=gnd(n155)
N217=gnd(n156)
N218=gnd(n157)
N219=gnd(n158)
N220=gnd(n159)
N221=gnd(n160)
N222=gnd(n161)
N223=gnd(n162)
N224=gnd(n163)
N225=gnd(n164)
N226=gnd(n165)
N227=gnd(n166)
N228=vcc(n167)
N229=vcc(n168)
N230=vcc(n169)
N231=vcc(n170)
N232=vcc(n171)
N233=vcc(n172)
N234=vcc(n173)
N235=vcc(n174)
N236=vcc(n175)
N237=vcc(n176)
N238=vcc(n177)
N239=vcc(n178)
N240=vcc(n179)
N241=vcc(n180)
N242=vcc(n181)
N243=vcc(n182)
N244=vcc(n183)
N245=vcc(n184)
N246=vcc(n185)
N247=vcc(n186)
N248=vcc(n187)
N249=vcc(n188)
N250=vcc(n189)
N251=vcc(n190)
N252=vcc(n191)
N253=vcc(n192)
n0~precharge
n9~latched_nano.24
n13~latched_nano.28
n14~latched_nano.27
n15~latched_nano.26
n33~mbus_rega_d_id.1'0
n34~mbus_rega_d_id.0'0
n35~mbus_rega_l_id.0'0
n36~mbus_rega_l_id.1'0
n43~mbus_regd_l_id.0'0
n45~mbus_regd_l_id.1'0
n46~mbus_rega_l_id.4'0
n47~mbus_rega_l_id.2'0
n52~mbus_rega_l_id.a'0
n53~mbus_regd_l_id.4'0
n56~mbus_rega_l_id.b'0
n57~mbus_regd_l_id.5'0
n84~mbc_b0.15
n86~mbc_b0.14
n87~mbc_b0.13
n88~mbc_b0.12
]])

move(nl, 0, 0, [[
N83  1983 2418 en38,
N168 1982 2422,
N32  1983 2410 en136,
N197 1982 2406,

N84  1997 2418 en40,
N169 1996 2422,
N33  1997 2410 en137,
N198 1996 2406,

N87  2011 2418 en55,
N237 2010 2422,
N40  2011 2410 en144,
N205 2010 2406,

N90  2025 2418 en58,
N240 2024 2422,
N47  2025 2410 en151,
N212 2024 2406,


N81  1960 2402 wn35,
N166 1961 2406,
N26  1962 2394 en130,
N191 1961 2390,
N27  1976 2394 en131,
N192 1975 2390,
N28  1990 2394 en132,
N193 1989 2390,

N89  1960 2380 wn57,
N239 1961 2384,
N46  1969 2372 en150,
N211 1968 2368,
N44  2004 2372 en148,
N209 2003 2368,
N45  2018 2372 en149,
N210 2017 2368,

N82  1960 2358 wn36,
N167 1961 2362,
N29  1962 2350 en133,
N194 1961 2346,
N30  1976 2350 en134,
N195 1975 2346,
N31  1997 2350 en135,
N196 1996 2346,

N86  1960 2336 wn53,
N236 1961 2340,
N39  1969 2328 en143,
N204 1968 2324,
N38  2018 2328 en142,
N203 2017 2324,
N37  2011 2328 en141,
N202 2010 2324,

N80  1960 1927 wn34,
N165 1961 1931,
N23  1962 1919 en127,
N188 1961 1915,
N24  1983 1919 en128,
N189 1982 1915,
N25  1990 1919 en129,
N190 1989 1915,

N88  1960 1905 wn56,
N238 1961 1909,
N43  1969 1897 en147,
N208 1968 1893,
N41  2004 1897 en145,
N206 2003 1893,
N42  2025 1897 en146,
N207 2024 1893,

N79  1960 1883 wn33,
N164 1961 1887,
N20  1962 1875 en124,
N185 1961 1871,
N21  1983 1875 en125,
N186 1982 1871,
N22  1997 1875 en126,
N187 1996 1871,

N85  1960 1861 wn52,
N235 1961 1865,
N36  1969 1853 en140,
N201 1968 1849,
N34  2011 1853 en138,
N199 2010 1849,
N35  2025 1853 en139,
N200 2024 1849,


N78  2010 2520 en31,
N163 2009 2524,
N18  2010 2512 en122,
N183 2009 2508,
N19  2008 2504 en123,
N184 2007 2500,
N76  2018 2520 wn26,
N161 2019 2524,
N15  2018 2512 wn119,
N180 2019 2508,
N16  2020 2504 wn120,
N181 2021 2500,

N69  2030 2520 en12,
N234 2029 2524,
N7   2030 2512 en111,
N172 2029 2508,
N8   2028 2504 en112,
N173 2027 2500,
N70  2038 2520 wn18,
N155 2039 2524,
N9   2038 2512 wn113,
N174 2039 2508,
N10  2040 2504 wn114,
N175 2041 2500,

N96  2050 2520 en70,
N246 2049 2524,
N53  2050 2512 en157,
N218 2049 2508,
N52  2048 2504 en156,
N217 2047 2500,
N95  2058 2520 wn69,
N245 2059 2524,
N51  2058 2512 wn155,
N216 2059 2508,
N50  2060 2504 wn154,
N215 2061 2500,

N68  2070 2520 en11,
N233 2069 2524,
N5   2070 2512 en109,
N170 2069 2508,
N6   2068 2504 en110,
N171 2067 2500,
N99  2078 2520 wn78,
N249 2079 2524,
N57  2078 2512 wn161,
N222 2079 2508,
N58  2080 2504 wn162,
N223 2081 2500,


N77  2020 2490 wn30,
N162 2021 2494,
N17  2026 2490 en121,
N182 2025 2486,

N94  2060 2490 wn64,
N244 2061 2494,
N49  2066 2490 en153,
N214 2065 2486,


N72  1969 2506 en24,
N157 1968 2510,
N73  1976 2506 en24,
N158 1975 2510,
N74  1983 2506 en24,
N159 1982 2510,
N13  1969 2498 en117,
N178 1968 2494,

N91  1976 2486 en60,
N241 1975 2490,
N92  1983 2486 en60,
N242 1982 2490,
N93  1990 2486 en60,
N243 1989 2490,
N48  1976 2478 en152,
N213 1975 2474,


N120 2090 2479 nn19,
N126 2090 2472 nn27,
N125 2090 2465 nn21,
N121 2090 2458 nn67,
N141 2090 2451 nn63,
N146 2090 2444 nn74,

N133 2050 2322 nn42,
N131 2050 2316 nn37,
N140 2050 2310 nn59,
N139 2050 2304 nn54,
N137 2050 2295 nn47,
N135 2050 2253 nn45,
N136 2050 2211 nn46,
N134 2050 2169 nn43,

N122 2440 2201 nn17,
N67  2426 2200 wn10,
N232 2427 2204,
N4   2432 2200 en93,
N154 2431 2196,

N128 2140 2480 nn28,
N127 2140 2474 nn28,
N12  2140 2468 nn23, N177 2144 2467,
N123 2140 2462 nn23,
N129 2140 2456 nn71,
N130 2140 2450 nn71,
N124 2140 2444 nn76,
N56  2140 2438 nn76, N221 2144 2437,
N108 2140 2346 nn41,
N110 2140 2340 nn41,
N106 2140 2334 nn39,
N104 2140 2328 nn39,
N105 2140 2322 nn61,
N107 2140 2316 nn61,
N111 2140 2310 nn62,
N109 2140 2304 nn62,
N115 2140 2295 nn50,
N113 2140 2289 nn50,
N112 2140 2259 nn49,
N114 2140 2253 nn49,
N117 2140 2217 nn51,
N119 2140 2211 nn51,
N118 2140 2175 nn44,
N116 2140 2169 nn44,


N75  2104 2388 en25,
N160 2103 2392,
N14  2102 2380 wn118,
N179 2103 2376,

N71  2114 2388 en22,
N156 2113 2392,
N11  2112 2380 wn115,
N176 2113 2376,

N63  2201 2342 en1,
N228 2200 2346,
N0   2201 2334 en89,
N150 2200 2330,
N97  2209 2342 wn73,
N247 2210 2346,
N54  2209 2334 wn158,
N219 2210 2330,
N138 2220 2328 nn72,
N145 2190 2328 nn84,

N66  2201 2312 en8,
N231 2200 2316,
N3   2201 2304 en92,
N153 2200 2300,
N100 2209 2312 wn79,
N250 2210 2316,
N59  2209 2304 wn163,
N224 2210 2300,
N142 2220 2298 nn77,
N147 2190 2298 nn88,

N65  2201 2282 en5,
N230 2200 2286,
N2   2201 2274 en91,
N152 2200 2270,
N101 2209 2282 wn81,
N251 2210 2286,
N60  2209 2274 wn164,
N225 2210 2270,
N143 2220 2268 nn80,
N148 2190 2268 nn87,

N64  2201 2252 en4,
N229 2200 2256,
N1   2201 2244 en90,
N151 2200 2240,
N102 2209 2252 wn83,
N252 2210 2256,
N61  2209 2244 wn165,
N226 2210 2240,
N144 2220 2238 nn82,
N149 2190 2238 nn86,

N103 2200 2222 en85,
N253 2199 2226,
N62  2200 2214 en166,
N227 2199 2210,
N98  2210 2222 wn75,
N248 2211 2226,
N55  2210 2214 wn159,
N220 2211 2210,
]])

route(nl, 0, 0, [[
n38  1980 2414,
n40  1994 2414,
n55  2008 2414,
n58  2022 2414,

n35  1937 2402,
n57  1937 2380,
n36  1937 2358,
n53  1937 2336,

n34  1937 1927,
n56  1937 1905,
n33  1937 1883,
n52  1937 1861,

n31  2007 2516,
n26  2021 2516,

n12  2027 2516,
n18  2041 2516,

n70  2047 2516,
n69  2061 2516,

n11  2067 2516,
n78  2081 2516,

n19  2014 2507 2014 2497 2024 2497 2034 2497,
n67  2054 2497 2074 2497,
n30  2023 2494 2023 2486,
n64  2063 2494 2063 2486,
n24  1966 2502,
n60  1973 2482,

n19  1973 2515 2004 2515 2004 2505 2004 2495 2004 2485 2004 2478 2014 2478 2024 2478 2034 2478 2034 2488 2034 2498,
n21  1980 2513 2002 2513 2002 2488 2002 2464 2036 2464 2036 2488,
n27  2000 2506 2000 2471 2030 2471,
n63  1980 2495 1998 2495 1998 2450 2070 2450,
n67  1987 2493 1996 2493 1996 2457 2046 2457 2074 2457,
n74  1994 2443 2076 2443,

n0   2086 2483 2086 2476 2086 2469 2086 2462 2086 2455 2086 2448 2086 2441 2046 2441 2046 2326 2046 2320 2046 2314 2046 2308 2046 2299 2046 2257 2046 2215 2046 2173 2046 2166 1896 2166,
n42  2001 2321,
n37  1987 2315,
n59  2029 2309,
n54  2015 2303,
n47  1935 2294,
n45  1935 2252,
n46  1935 2210,
n43  1935 2168,

n0   2092 2441 2440 2441 2473 2441,
n10  2429 2204 2429 2196 2346 2200 2346 2962 2294 2962 2294 3082,

n3   2162 2345 2162 2303,
n4   2158 2339 2158 2309,
n2   2164 2333 2164 2315 2153 2333 2154 2315,
n1   2154 2327 2154 2321 2149 2327 2150 2321,
n6   2166 2294 2166 2252,
n5   2160 2288 2160 2258,
n8   2156 2210 2156 2174,
n7   2168 2216 2168 2168,

n22  2134 2350 2134 2338 2134 2326 2134 2314 2134 2299 2134 2263 2134 2221 2134 2179 2134 2484 2134 2472 2134 2460 2134 2448 2134 2388,
n25  2132 2344 2132 2332 2132 2320 2132 2308 2132 2293 2132 2257 2132 2215 2132 2173 2132 2478 2132 2466 2132 2454 2132 2442 2108 2372 2132 2372,

n28  2094 2473,
n23  2136 2464,
n71  2136 2450,
n61  2130 2315 2130 2309,
n39  2128 2327 2128 2315,
n41  2126 2339 2126 2321,

n72  2205 2327,
n1   2154 2338,

n77  2205 2297,
n8   2156 2308,

n80  2205 2267,
n5   2160 2278,

n82  2205 2237,
n4   2158 2248,

n75  2216 2332 2216 2302 2216 2272 2216 2242 2216 2218,
n85  2194 2332 2194 2302 2194 2272 2194 2242 2194 2218,

n48  2388 2327 2388 2300,
n65  2388 2297 2388 2270,
n66  2388 2267 2388 2263,
n68  2388 2237 2388 2256,

n32  2146 2479 2146 2449 2446 2449 2446 2326,
n29  2148 2473 2148 2455 2444 2455 2444 2354,
n20  2150 2461 2150 2443 2442 2443 2442 2384,
]])



rename(megabus_control, "euc.")
















