microcode = {
   nano_top = {},
   nano_top_postsel = {},
   nano_top_latched = {},
   nano_bot = {},
   nano_bot_postsel = {},
   nano_bot_latched = {},
   nano_test = {},
   micro_top = {},
   micro_top_postsel = {},
   micro_top_postsel2 = {},
   micro_top_latched = {},
   micro_bot = {},
   micro_bot_postsel = {},
   micro_bot_postsel2 = {},
   micro_bot_latched = {},
}

local function selsort(n)
   if(#n ~= 4) then
      print("nano top bad node count "..#n)
      os.exit(1);
   end

   local nc = {}
   local xl = {}
   local xn = {}
   for j=1,4 do
      local x,y = n[j]:pos()
      xl[j] = x
      xn[x] = n[j]
      local net = n[j]:t1()
      if(nc[net]) then
	 nc[net] = nc[net]+1
      else
	 nc[net] = 1
      end
      net = n[j]:t2()
      if(nc[net]) then
	 nc[net] = nc[net]+1
      else
	 nc[net] = 1
      end
   end
   table.sort(xl)
   local cnet
   for k, v in pairs(nc) do
      if(v == 4) then
	 cnet = k
      end
   end
   if(not cnet) then
      print("nano top cnet not found")
      os.exit(1);
   end

   local r = { nodes={}, onets={}, gates={}, cnet=cnet }
   for j=1,4 do
      local node = xn[xl[j]]
      local onet = node:t1()
      if(onet == cnet) then
	 onet = node:t2()
      end
      r.nodes[j] = node
      r.onets[j] = onet
      r.gates[j] = node:gate()
   end
   return r
end

local function drivesort(n, limits)
   local nc = {{},{},{},{}}
   local xl = {}
   local xn = {}
   local ns = {}
   for j=1,118 do
      local x,y = n[j]:pos()
      local slot = 4
      for k=3,1,-1 do
	 if(y < limits[k]) then
	    slot = k
	 end
      end
      xl[j] = x
      xn[x] = n[j]
      ns[n[j]] = slot
      local net = n[j]:t1()
      if(nc[slot][net]) then
	 nc[slot][net] = nc[slot][net]+1
      else
	 nc[slot][net] = 1
      end
      net = n[j]:t2()
      if(nc[slot][net]) then
	 nc[slot][net] = nc[slot][net]+1
      else
	 nc[slot][net] = 1
      end
   end
   table.sort(xl)

   local r = { hsel={}, vsel={}, vin={}, nodes={}, slots={} }

   for j=1,4 do
      for net,count in pairs(nc[j]) do
	 if(count > 1) then
	    r.hsel[j] = net
	 end
      end
   end
   for j=1,118 do
      local node = xn[xl[j]]
      local slot = ns[node]
      r.nodes[j] = node
      r.slots[j] = slot
      local vsel = node:t1()
      if(vsel == r.hsel[slot]) then
	 vsel = node:t2()
      end
      r.vsel[j] = vsel
      r.vin[j] = node:gate()
   end
   return r
end

local function drivers_place(drivers, f1, f2)
   for i=1,118,2 do
      local x = 3074 + 8*i
      if(i >= 42*2) then
	 x = x + 20
      end
      f1(drivers.nodes[i],   x, drivers.slots[i],   drivers.hsel[drivers.slots[i]],   drivers.vsel[i],   drivers.vin[i])
      f2(drivers.nodes[i+1], x, drivers.slots[i+1], drivers.hsel[drivers.slots[i+1]], drivers.vsel[i+1], drivers.vin[i+1])
   end
end

local function rom_place(n, inputs, outputs, place_odd, place_even)
   local gl = {}
   local dl = {}
   local ol = {}
   for k,v in pairs(outputs) do
      ol[v] = k
   end
   for i=1,118 do
      dl[inputs.vsel[i]] = i
   end
   for i=1,#n do
      if(n[i]:type() == "w") then
	 gl[n[i]:t1()] = n[i]
      end
   end
   for i=1,#n do
      if(n[i]:type() == "t") then
	 local t = n[i]
	 local vsel = t:gate()
	 local vout = t:t1()
	 local gnd = t:t2()
	 if(ol[gnd]) then
	    local t = gnd
	    gnd = vout
	    vout = t
	 end
	 local gnode = gl[gnd]
	 local vseli = dl[vsel]
	 local vouti = ol[vout]

	 if(vouti) then
	    local b1 = vouti % 4
	    local b4 = math.floor(vouti / 4) % 4
	    local b16 = math.floor(vouti / 16)
	    if((vseli % 2) == 1) then
	       place_odd(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	    else
	       place_even(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	    end
	 else
	    print(vseli, vouti)
	 end
      end
   end
end

local nslots = { 3, 1, 2, 0 }
local mslots = { 3, 1, 2, 0 }

for b=0,7 do
   local y1 = 4173 - 131*b
   for i=0,3 do
      local y2 = y1 - 29*i 
      local n = nodes_rect(3029, y2, 3066, y2-28)

      local r = selsort(n)
      r.cnet:route(3029, y2-3, 3029, y2-10, 3029, y2-17, 3029, y2-24,
		   3035, y2-3, 3035, y2-10, 3035, y2-17,
		   3041, y2-3, 3041, y2-10, 3041, y2-17,
		   3029, y2-7, 3029, y2-14, 3029, y2-21)

      if(b == 0 and i == 0) then
	 microcode.nano_sel = r.gates
      end
      
      microcode.nano_top_postsel[b*4+i] = r.cnet
      for j=1,4 do
	 microcode.nano_top[b*16+i*4+nslots[j]] = r.onets[j]
	 r.nodes[j]:move(3038+(j-1)*10, y2-4-7*nslots[j], "s", r.cnet)
	 r.gates[j]:route(3033+(j-1)*10, y2-8-7*nslots[j])
      end

      n = nodes_rect(4070, y2, 4116, y2-28)

      r = selsort(n)
      r.cnet:route(4098, y2-3, 4098, y2-10, 4098, y2-17, 4098, y2-24,
		   4092, y2-3, 4092, y2-10, 4092, y2-17,
		   4086, y2-3, 4086, y2-10, 4086, y2-17,
		   4098, y2-7, 4098, y2-14, 4098, y2-21)
      
      microcode.micro_top_postsel[b*4+i] = r.cnet
      for j=1,4 do
	 microcode.micro_top[b*16+i*4+mslots[j]] = r.onets[j]
	 r.nodes[j]:move(4089-(j-1)*10, y2-4-7*mslots[j], "s", r.onets[j])
	 r.gates[j]:route(4094-(j-1)*10, y2-8-7*mslots[j])
      end
   end
end

for b=0,8 do
   local y1 = 2792 - 131*b
   for i=0,3 do
      local y2 = y1 - 29*i 
      local n = nodes_rect(3029, y2, 3066, y2-28)

      local r = selsort(n)
      r.cnet:route(3029, y2-3, 3029, y2-10, 3029, y2-17, 3029, y2-24,
		   3035, y2-3, 3035, y2-10, 3035, y2-17,
		   3041, y2-3, 3041, y2-10, 3041, y2-17,
		   3029, y2-7, 3029, y2-14, 3029, y2-21)
      
      microcode.nano_bot_postsel[b*4+i] = r.cnet
      for j=1,4 do
	 microcode.nano_bot[b*16+i*4+nslots[j]] = r.onets[j]
	 r.nodes[j]:move(3038+(j-1)*10, y2-4-7*nslots[j], "s", r.cnet)
	 r.gates[j]:route(3033+(j-1)*10, y2-8-7*nslots[j])
      end

      n = nodes_rect(4070, y2, 4116, y2-28)

      r = selsort(n)
      r.cnet:route(4098, y2-3, 4098, y2-10, 4098, y2-17, 4098, y2-24,
		   4092, y2-3, 4092, y2-10, 4092, y2-17,
		   4086, y2-3, 4086, y2-10, 4086, y2-17,
		   4098, y2-7, 4098, y2-14, 4098, y2-21)
      
      microcode.micro_bot_postsel[b*4+i] = r.cnet
      for j=1,4 do
	 microcode.micro_bot[b*16+i*4+mslots[j]] = r.onets[j]
	 r.nodes[j]:move(4089-(j-1)*10, y2-4-7*mslots[j], "s", r.onets[j])
	 r.gates[j]:route(4094-(j-1)*10, y2-8-7*mslots[j])
      end
   end
end

microcode.drivers_top = drivesort(nodes_rect(3074, 3107, 4042, 3077), { 3085, 3093, 3102 })

drivers_place(microcode.drivers_top,
	      function(n, x, slot, hsel, vsel, gate)
		 local y = 3107-10*(slot-1)
		 n:move(x,    y, "e", hsel)
		 gate:route(x+4, y-6, x+1, y-6)
	      end,
	      function(n, x, slot, hsel, vsel, gate)
		 local y = 3107-10*(slot-1)
		 n:move(x+12, y, "w", hsel)
		 gate:route(x+8, y-6, x+9, y-6)
	      end)

rom_place(nodes_rect(3070, 4176, 3760, 3136), microcode.drivers_top, microcode.nano_top,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 8*vseli
	     local y = 4171 - 131*b16 - 29*b4 - 7*b1
	     t:move(x+1, y+1, "n", vout)
	     gnode:move(x+5, y)
	     vout:route(x-4, y, x-4, y-1, x-6, y-1)
	     vsel:route(x-3, y+5)
	  end,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 8*vseli
	     local y = 4171 - 131*b16 - 29*b4 - 7*b1
	     t:move(x-1, y+4, "s", gnd)
	     gnode:move(x-5, y+5)
	     vout:route(x+4, y+5, x+4, y-1, x-4, y-1)
	     vsel:route(x+3, y)
	  end)

rom_place(nodes_rect(3760, 4176, 4045, 3136), microcode.drivers_top, microcode.micro_top,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 20 + 8*vseli
	     local y = 4171 - 131*b16 - 29*b4 - 7*b1
	     t:move(x+1, y+1, "n", vout)
	     gnode:move(x+5, y)
	     vout:route(x-4, y, x-4, y-1, x-2, y-1)
	     vsel:route(x-3, y+5)
	  end,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 20 + 8*vseli
	     local y = 4171 - 131*b16 - 29*b4 - 7*b1
	     t:move(x-1, y+4, "s", gnd)
	     gnode:move(x-5, y+5)
	     vout:route(x+4, y+5, x+4, y-1, x+8, y-1)
	     vsel:route(x+3, y)
	  end)

microcode.drivers_bot = drivesort(nodes_rect(3074, 2861, 4042, 2828), { 2835, 2845, 2852 })

drivers_place(microcode.drivers_bot,
	      function(n, x, slot, hsel, vsel, vin)
		 local y = 2861-10*(slot-1)
		 n:move(x,    y, "e", vsel)
		 vin:route(x+4, y+6, x+1, y+6)
	      end,
	      function(n, x, slot, hsel, vsel, vin)
		 local y = 2861-10*(slot-1)
		 n:move(x+12, y, "w", vsel)
		 vin:route(x+8, y+6, x+9, y+6)
	      end)

rom_place(nodes_rect(3070, 2800, 3760, 1627), microcode.drivers_bot, microcode.nano_bot,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 8*vseli
	     local y = 2790 - 131*b16 - 29*b4 - 7*b1
	     t:move(x+1, y+1, "n", vout)
	     gnode:move(x+5, y)
	     vout:route(x-4, y, x-4, y-1, x-6, y-1)
	     vsel:route(x-3, y+5)
	  end,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 8*vseli
	     local y = 2790 - 131*b16 - 29*b4 - 7*b1
	     t:move(x-1, y+4, "s", gnd)
	     gnode:move(x-5, y+5)
	     vout:route(x+4, y+5, x+4, y-1, x-4, y-1)
	     vsel:route(x+3, y)
	  end)

rom_place(nodes_rect(3760, 2800, 4045, 1627), microcode.drivers_bot, microcode.micro_bot,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 20 + 8*vseli
	     local y = 2790 - 131*b16 - 29*b4 - 7*b1
	     t:move(x+1, y+1, "n", vout)
	     gnode:move(x+5, y)
	     vout:route(x-4, y, x-4, y-1, x-2, y-1)
	     vsel:route(x-3, y+5)
	  end,
	  function(t, gnode, vout, vsel, gnd, vseli, b1, b4, b16)
	     local x = 3076 + 20 + 8*vseli
	     local y = 2790 - 131*b16 - 29*b4 - 7*b1
	     t:move(x-1, y+4, "s", gnd)
	     gnode:move(x-5, y+5)
	     vout:route(x+4, y+5, x+4, y-1, x+8, y-1)
	     vsel:route(x+3, y)
	  end)

for region=0,1 do
   local nps, npl
   if(region == 0) then
      npl = microcode.nano_top_latched
      nps = microcode.nano_top_postsel 
   else
      npl = microcode.nano_bot_latched
      nps = microcode.nano_bot_postsel 
   end
   for b=0,7+region do
      for i=0,1 do
	 local yy = 4110 - 1381*region - 131*b - 58*i
	 local bn = i*2 + b*4
	 local n = nodes_rect(2885, yy+68, 3025, yy)
	 local nl1 = match(n, "P0=t(l0, p, vp) P1=t(l1, p, vp) T=d(v, g, vp) V=vcc(v) G=gnd(g)", {l0=nps[bn], l1=nps[bn+1]})

	 move(nl1, 2885, yy, "P0 130 35 evp, P1 130 14 el1, T 125 24 sv, V 121 25, G 125 20")
	 if(i==0 and b==0 and region==0) then
	    nl1.p:set_name("romarray_precharge")
	    nl1.p:route(4188, 1621, 4188, 1642, 4901, 1642, 4901, 1877, 4962, 1877, 4962, 1888)
	 end
	 for slot=0,1 do
	    local yy1 = yy + 29*(1-slot)
	    local nl2 = match(n, "T1=t(i,l,g1) T2=d(v,i,i) G1=gnd(g1) V=vcc(v) T3=t(i,lc,i2) Z=t(i2,z,g2) G2=gnd(g2)", {l=nps[bn+slot]})
	    if(nl2) then
	       if(i==0 and b==0 and region==0) then
		  nl2.z:set_name("romarray_clear")
		  nl2.z:route(4186, 1625, 2979, 1625, 4186, 1644, 4905, 1644, 4962, 1788, 4962, 1777, 4905, 1777)
	       end
	       move(nl2, 2885, yy1, "T1 110 10 eg1, T2 110 18 ei, G1 109 6, V 109 22, T3 100 18 ei, Z 90 18 eg2, G2 89 14")
	       route(nl2, 2885, yy1, "i2 86 22 86 2 77 2")
	    else
	       nl2 = match(n, "T1=t(i,l,g1) T2=d(v,i,i) G1=gnd(g1) V=vcc(v) T3=t(i,lc,i2) Z=t(i2,z,v2) V2=vcc(v2)", {l=nps[bn+slot]})
	       move(nl2, 2885, yy1, "T1 110 10 eg1, T2 110 18 ei, G1 109 6, V 109 22, T3 100 18 ei, Z 90 26 ei2, V2 89 30")
	       route(nl2, 2885, yy1, "i2 86 22 86 2 77 2")
	    end
	    local nl3 = latch(n, 2950, yy1+4, { ri=nl2.i2})
	    local nl4 = match(n, "T4=t(o,ro,v) T5=t(o, nr, g) V=vcc(v) G=gnd(g)", nl3)
	    if(nl4) then
	       move(nl4, 2885, yy1, "T4 57 18 eo, T5 57 10 eg, V 56 22, G 56 6")
	       route(nl4, 2885, yy1, "nr 61 10 61 8 74 8 74 14")
	    else
	       nl4 = match(n, "T4=t(o,nr,v) T5=t(o, ro, g) V=vcc(v) G=gnd(g)", nl3)
	       move(nl4, 2885, yy1, "T4 57 18 eo, T5 57 10 eg, V 56 22, G 56 6")
	       route(nl4, 2885, yy1, "nr 61 8 74 8 74 14, ro 65 10")
	    end
	    npl[bn+slot] = nl4.o
	 end
      end
   end
end

local n = nodes_rect(2855, 4166, 2885, 1634)

for region=0,1 do
   local npl
   if(region == 0) then
      npl = microcode.nano_top_latched
   else
      npl = microcode.nano_bot_latched
   end
   for b=0,7+region do
      for i=0,1 do
	 for slot=0,1 do
	    local yy = 4149 - 1381*region - 131*b - 58*i - 29*slot
	    local bn = i*2 + b*4 + slot
	    local bn1 = bn + 32*region
	    local xx = bn1 % 3
	    local inp = npl[i*2 + b*4 + slot]
	    local nl = match(n, "A=t(i, t, o)", {i=inp})
	    nl.A:move(2900 - 10*xx, yy, "w", nl.o)
	    if(bn1<3) then
	       microcode.nano_test[bn1] = nl.t
	    end
	    if(xx ~= 0) then
	       nl.o:route(2911 - 10*xx, yy-4)
	    end
	 end
      end
   end
end

local n = nodes_rect(2745, 4200, 2855, 4090)
local nl = match(n, [[
N0=t(t0, n3, n6)
N1=t(t0, n4, n7)
N2=t(t0, n5, n8)
N3=t(n3, n1, n9)
N4=t(t1, n1, n10)
N5=t(t1, n4, n11)
N6=t(t1, n5, n12)
N7=t(t2, n0, n13)
N8=t(n14, n3, t2)
N9=t(t2, n5, n15)
N10=t(n4, n0, n16)
N11=t(n17, n2, n5)
N12=d(t0, t0, n18)
N13=d(n3, n3, n19)
N14=d(t1, t1, n20)
N15=d(n21, t2, t2)
N16=d(n4, n4, n22)
N17=d(n5, n5, n23)
N18=gnd(n6)
N19=gnd(n7)
N20=gnd(n8)
N21=gnd(n9)
N22=gnd(n10)
N23=gnd(n11)
N24=gnd(n12)
N25=gnd(n13)
N26=gnd(n14)
N27=gnd(n15)
N28=gnd(n16)
N29=gnd(n17)
N30=vcc(n18)
N31=vcc(n19)
N32=vcc(n20)
N33=vcc(n21)
N34=vcc(n22)
N35=vcc(n23)
]], { t0=microcode.nano_test[0], t1=microcode.nano_test[1], t2=microcode.nano_test[2] })

move(nl, 2870, 4270, [[
N12 30 40 wt0,
N30 31 44,
N14 20 20 wt1,
N32 21 24,
N15 10 0 wt2,
N33 11 4,

N0 -10 36 wn6,
N18 -9 32,
N1 -30 36 wn7,
N19 -29 32,
N2 -50 36 wn8,
N20 -49 32,

N4 0 16 wn10,
N22 1 12,
N5 -30 16 wn11,
N23 -29 12,
N6 -50 16 wn12,
N24 -49 12,

N8 -10 -4 wn14,
N26 -9 -8,
N7 -20 -4 wn13,
N25 -19 -8,
N9 -50 -4 wn15,
N27 -49 -8,

N13 -8 62 en3,
N31 -9 66,
N3 -8 54 en9,
N21 -9 50,

N16 -28 62 en4,
N34 -29 66,
N10 -28 54 en16,
N28 -29 50,

N17 -48 62 en5,
N35 -49 66,
N11 -48 54 en17,
N29 -49 50,
]])

route(nl, 2870, 4270, [[
n5 -54 58,
n4 -34 58,
n3 -14 58,
n2 -44 -15 -88 -15 -1276 -15,
n0 -22 54 -22 91 1736 91,
n1 -2 54 -2 89 1761 89,
]])

nl.n0:route(2846, 4245, 2422, 4245, 2422, 3810, 2156, 3810, 2156, 2808, 1959, 2808, 1959, 2739)
nl.n1:route(2866, 4243, 2424, 4243, 2424, 3808, 2158, 3808, 2158, 2806, 1961, 2806, 1961, 2689)

local n = nodes_rect(4130, 4180, 4250, 3150)
n = merge(n, nodes_rect(4130, 2800, 4250, 1630))

for region=0,1 do
   local nps, npl
   if(region == 0) then
      npl = microcode.micro_top_latched
      nps = microcode.micro_top_postsel 
      nps2 = microcode.micro_top_postsel2
   else
      npl = microcode.micro_bot_latched
      nps = microcode.micro_bot_postsel
      nps2 = microcode.micro_bot_postsel2
   end
   for b=0,7+region do
      for i=0,1 do
	 local yy = 4110 - 1381*region - 131*b - 58*i
	 local nl = match(n, [[
PR=d(prv, prg, pl)
PRV=vcc(prv)
PRG=gnd(prg)
PLT=t(lt, pr, pl)
PLB=t(lb, pr, pl)
ST=t(lt, s0, sel)
SB=t(lb, s1, sel)
]], { lt = nps[4*b+2*i], lb = nps[4*b+2*i+1] })

	 move(nl, 4110, yy, [[
PLT 0 35 wpl,
PLB 0 14 wlb,
PR  5 24 spl,
PRV 9 25,
PRG 5 20,
]])
	 move(nl, 4140-20*i, yy, [[
ST 10 38 slt,
SB  0  9 slb,
]])
	 route(nl, 4140-20*i, yy, [[
s0 14 34,
s1 4 5,
]])
	 nl.sel:route(4160, yy+39, 4160, yy+10)
	 if(i == 0) then
	    nps2[b] = nl.sel
	 end
      end
      local yy = 4110 - 1381*region - 131*b
      local nl = match(n, [[
IV=d(v, is, is)
IG=t(is, sel, g)
V=vcc(v)
G=gnd(g)
L=t(is, l0, ri)
]], { sel = nps2[b] })
      local cl = match(n, [[
CL=t(ri, cl, g)
G=gnd(g)
]], { ri = nl.ri })
      move(nl, 4170, yy, [[
IV 0 47 wis,
V 1 51,
IG 0 39 wg,
G 1 35,
L 10 47 wis,
]])
      route(nl, 4170, yy, [[
ri 24 51 24 31 33 31,
]])
      if(cl) then
	 move(cl, 4170, yy, [[
CL 20 47 wg,
G 21 43,
]])
      end
      local ll = latchi(n, 4215, yy+33, { ri = nl.ri })
      local dl = match(n, [[
DV=t(v,ro,o)
V=vcc(v)
DG=t(o,nr,g)
G=gnd(g)
]], ll)
      if(dl) then
	 move(dl, 4220, yy, [[
DV 3 47 wo,
V 4 51,
DG 3 39 wg,
G 4 35
]])
	 route(dl, 4220, yy, [[
nr -1 37 -14 37 -14 43,
]])
	 npl[b] = dl.o
      else
	 local dl = match(n, [[
DV=t(v,nr,o)
V=vcc(v)
DG=t(o,ro,g)
G=gnd(g)
]], ll)
	 if(dl) then
	    move(dl, 4220, yy, [[
DV 3 47 wo,
V 4 51,
DG 3 39 wg,
G 4 35
]])
	    route(dl, 4220, yy, [[
nr -1 37 -14 37 -14 43,
ro -5 39,
]])
	    npl[b] = dl.o
	 end
      end
   end
end

local n = nodes_rect(3070, 3055, 4050, 3030)

for i=1,118 do
   local nl = match(n, [[
PD=t(i, v1, o)
V1=vcc(v1)
DU=t(i, c, v2)
V2=vcc(v2)
]], { o=microcode.drivers_top.vin[i] })
   local xx = 3074 + 8*i
   if(i > 42*2) then
      xx = xx + 20
   end
   move(nl, xx, 3060, [[
PD 0 0 wi,
V1 -4 0,
DU -2 -15 wi,
V2 -1 -11,
]])
   route(nl, xx, 3060, "i 1 -19, c -6 -21")
end

local n = nodes_rect(3070, 2930, 4050, 2880)

local xmap = {}
for i=1,118 do
   local nl = match(n, [[
PD=t(i, v1, o)
V1=vcc(v1)
DD=t(i, c, g2)
G2=gnd(g2)
]], { o=microcode.drivers_bot.vin[i] })
   local xx = 3074 + 8*i
   if(i > 42*2) then
      xx = xx + 20
   end
   move(nl, xx, 2890, [[
PD 0 0 wo,
V1 -4 0,
DD -2 15 wg2,
G2 -1 11,
]])
   route(nl, xx, 2890, "i 1 19")
   nl.c:route(xx-6, 2898 + (i % 2)*13)
   xmap[nl.i] = i
end

local map = {}
for i=0,9 do
   local n = named_net(string.format("mdrive.%d", i))
   map[n] = i
end

local n = nodes_rect(3070, 3020, 4050, 2920)
for i=1,#n do
   local drive = map[n[i]:gate()]
   local vline = n[i]:t1()
   local vli = xmap[vline]
   if(not vli) then
      vline = n[i]:t2()
      vli = xmap[vline]
   end
   local xx = 3072 + 8*vli
   if(vli > 42*2) then
      xx = xx + 20
   end
   local yy = 3026-10*drive
   n[i]:move(xx, yy, "w", vline)
   vline:route(xx+3, yy-4)
   n[i]:gate():route(xx-4, yy-5)
end

local map = {
   s1 = microcode.nano_sel[1],
   s2 = microcode.nano_sel[2],
   s3 = microcode.nano_sel[3],
   s4 = microcode.nano_sel[4],
}

local n = nodes_rect(2900, 3125, 3040, 2810)
local nl = match(n, [[
N21=t(s1, n5, n33)
N53=vcc(n33)
N3=t(n20, n6, s1)
N40=gnd(n20)
N25=d(n37, n6, n6)
N57=vcc(n37)
N8=t(n16, n5, n6)
N36=gnd(n16)
N24=d(n5, n5, n36)
N56=vcc(n36)
N6=t(n5, n3, n14)
N34=gnd(n14)
N7=t(n15, n4, n5)
N35=gnd(n15)

N19=t(n31, n7, s2)
N51=vcc(n31)
N1=t(n18, n8, s2)
N38=gnd(n18)
N27=d(n39, n8, n8)
N59=vcc(n39)
N11=t(n23, n7, n8)
N43=gnd(n23)
N26=d(n7, n7, n38)
N58=vcc(n38)
N9=t(n7, n2, n21)
N41=gnd(n21)
N10=t(n22, n4, n7)
N42=gnd(n22)

N20=t(s3, n9, n32)
N52=vcc(n32)
N2=t(n19, n0, s3)
N39=gnd(n19)
N29=d(n0, n0, n41)
N61=vcc(n41)
N14=t(n26, n9, n0)
N46=gnd(n26)
N28=d(n9, n9, n40)
N60=vcc(n40)
N13=t(n9, n3, n25)
N45=gnd(n25)
N12=t(n24, n1, n9)
N44=gnd(n24)

N18=t(n30, n10, s4)
N50=vcc(n30)
N0=t(n17, n11, s4)
N37=gnd(n17)
N31=d(n43, n11, n11)
N63=vcc(n43)
N17=t(n29, n10, n11)
N49=gnd(n29)
N30=d(n10, n10, n42)
N62=vcc(n42)
N16=t(n10, n2, n28)
N48=gnd(n28)
N15=t(n27, n1, n10)
N47=gnd(n27)

N22=d(n34, n3, n3)
N54=vcc(n34)
N4=t(n3, n2, n12)
N32=gnd(n12)

N23=d(n4, n4, n35)
N55=vcc(n35)
N5=t(n13, n1, n4)
N33=gnd(n13)
]], map)

move(nl, 0, 0, [[
N21 3014 3100 ws1,
N53 3015 3104,
N3  3014 3092 wn20,
N40 3015 3088,
N25 3006 3092 en6,
N57 3005 3096,
N8  3004 3084 wn16,
N36 3005 3080,
N24 2996 3084 en5,
N56 2995 3088,
N6  2994 3070 wn14,
N34 2995 3066,
N7  3000 3070 en15,
N35 2999 3066,

N19 3014 3010 ws2,
N51 3015 3014,
N1  3014 3002 wn18,
N38 3015 2998,
N27 3006 3002 en8,
N59 3005 3006,
N11 3004 2994 wn23,
N43 3005 2990,
N26 2996 2994 en7,
N58 2995 2998,
N9  2994 2980 wn21,
N41 2995 2976,
N10 3000 2980 en22,
N42 2999 2976,

N20 3014 2920 ws3,
N52 3015 2924,
N2  3014 2912 wn19,
N39 3015 2908,
N29 3006 2912 en0,
N61 3005 2916,
N14 3004 2904 wn26,
N46 3005 2900,
N28 2996 2904 en9,
N60 2995 2908,
N13 2994 2890 wn25,
N45 2995 2886,
N12 3000 2890 en24,
N44 2999 2886,

N18 3014 2830 ws4,
N50 3015 2834,
N0  3014 2822 wn17,
N37 3015 2818,
N31 3006 2822 en11,
N63 3005 2826,
N17 3004 2814 wn29,
N49 3005 2810,
N30 2996 2814 en10,
N62 2995 2818,
N16 2994 2800 wn28,
N48 2995 2796,
N15 3000 2800 en27,
N47 2999 2796,

N22 2960 3030 en3,
N54 2959 3034,
N4  2960 3022 en12,
N32 2959 3018,

N23 2960 2940 en4,
N55 2959 2944,
N5  2960 2932 en13,
N33 2959 2928,
]])

route(nl, 0, 0, [[
n3  2969 3030,
n2  2971 3022 2971 3037 4050 3037,
n4  2973 2940 2973 3025,
n1  2975 2932 2975 2835 2975 3035 4050 3035,

s1  3033 3096,
n5  3000 3100,
n3  2969 3070,
n4  3004 3063 2973 3063,

s2  3043 3006,
n7  3000 3010,
n2  2971 2980,
n4  3004 2973 2973 2973,

s3  3053 2916,
n9  3000 2920,
n3  2969 2890,
n1  3004 2883 2975 2883,

s4  3063 2826,
n10 3000 2830,
n2  2971 2800,
n1  3004 2793 2975 2793,
]])

local bl = {}

bl.i9a = named_net("clk_phase_mb_write")
bl.i10a = named_net("clk_phase_mb_write")

local n = nodes_rect(4335, 2596, 4349, 2579)
local nl = match(n, "A=t(d, a, b) B=d(b, b, c) C=vcc(c) D=gnd(d)")
move(nl, 0, 0, "B 4210 3132 eb, C 4209 3136, A 4210 3124 ed, D 4209 3120")
route(nl, 0, 0, "a 4222 3124, b 4224 3132")

bl.i7a = nl.b
bl.i8a = nl.b


local n = nodes_rect(4410, 2677, 4427, 2646)
local nl = match(n, "A=t(d, a, b) B=d(b, b, c) C=vcc(c) D=gnd(d)")
bl.i5a = nl.b
bl.i6a = nl.b

local n = nodes_rect(4303, 3094, 4314, 3077)
local nl = match(n, "A=t(d, a, b) B=d(b, b, c) C=vcc(c) D=gnd(d)")
move(nl, 0, 0, "B 4210 3112 eb, C 4209 3116, A 4210 3104 ed, D 4209 3100")
route(nl, 0, 0, "a 4220 3104 4066 3085 4066 3035, b 4218 3112")

bl.i3a = nl.a
bl.i4a = nl.a
bl.i1a = nl.b
bl.i2a = nl.b

local n = nodes_rect(4295, 3050, 4310, 3025)
local nl = match(n, "A=t(d, a, b) B=d(b, b, c) C=vcc(c) D=gnd(d)")
move(nl, 0, 0, "B 4210 3152 eb, C 4209 3156, A 4210 3144 ed, D 4209 3140")
route(nl, 0, 0, "a 4235 3144, b 4233 3152")
nl.a:route(4235, 3087, 4068, 3087, 4068, 3037)

local n = nodes_rect(4330, 2620, 4365, 2605)
local nl = match(n, "A=t(d, a, b) B=d(b, b, c) C=vcc(c) D=gnd(d)")
move(nl, 0, 0, "B 4210 3172 eb, C 4209 3176, A 4210 3164 ed, D 4209 3160")
route(nl, 0, 0, "a 4237 3164, b 4239 3172")

local n = nodes_rect(4277, 2979, 4287, 2973)
n = merge(n, nodes_rect(4288, 2956, 4294, 2946))
local nl = match(n, "A=t(d, a, b) B=d(b, b, c) C=vcc(c) D=gnd(d)")
move(nl, 0, 0, "B 4260 3114 wb, C 4261 3118, A 4266 3114 ed, D 4265 3110")
route(nl, 0, 0, "b 4263 3110 4263 3118 4237 3114")

local names = {
   "micro.vsel1",
   "micro.vsel2",
   "micro.vsel3",
   "micro.vsel4",
   "micro.vsel5",
   "micro.vsel6",
   "micro.vsel7",
   "micro.vsel8",
   "mdrive.10",
   "mdrive.11",
}

local n = nodes_rect(4180, 3100, 4430, 2490)
n = merge(n, nodes_rect(4230, 3280, 4430, 3100))


for i=1,#names do
   local nl = match(n, [[
A=t(f, d, a)
B=t(d, e, g)
C=t(h, b, e)
D=t(i, c, e)
E=t(a, e, j)
F=d(k, d, d)
G=d(e, e, l)
H=gnd(f)
I=gnd(g)
J=gnd(h)
K=gnd(i)
L=vcc(j)
M=vcc(k)
N=vcc(l)
]], { a = named_net(names[i]), b = bl[string.format("i%da", i)], c = bl[string.format("i%db", i)] })
   move(nl, 4190, 2850+25*(i-1), [[
E  1   0 ea,
L  0   4,
A  1  -8 ef,
H  0 -12,
F 11   0 wd,
M 12   4,
B 11  -8 wg,
I 12 -12,

G 21   0 we,
N 22   4,
C 23  -8 eh,
J 22 -12,
D 39  -8 ei,
K 38 -12,
]])

   route(nl, 4190, 2850+25*(i-1), [[
e 17 -15 17 -4 7 -15,
]])
   if((i%2) == 0) then
      local xa = 4216+i
      nl.b:route(xa, 2850+25*(i-1)-8, xa, 2850+25*(i-2)-8, xa, 3085)
   end
   if(((i-1)%4) < 2 and i < 10) then
      local xa = 4241
      if(i < 9) then
	 xa = 4233 + 2*((i-1)%4) + 4*math.floor((i-1)/4)
      end
      local yy = 2850+25*(i-1)
      nl.c:route(xa, yy-8)
      nl.c:route(xa, 3085)
      if(i < 9) then
	 nl.c:route(xa, yy-8+50)
      else
	 nl.c:route(xa, yy-8+25)
      end
   end

   bl[string.format("i%da", i)] = nl.b
   bl[string.format("i%db", i)] = nl.c
end

bl.i2b:route(4235, 2878)
bl.i3a:route(4220, 2848)
bl.i10a:route(4226, 3089, 4070, 3089, 4070, 3039, 4190, 3089)
bl.i10b:route(4241, 3100, 4456, 3100, 4456, 3030)

named_net("micro.vsel1"):route(4094, 2846)
named_net("micro.vsel2"):route(4084, 2871)
named_net("micro.vsel3"):route(4074, 2896)
named_net("micro.vsel4"):route(4064, 2921)
named_net("micro.vsel5"):route(4124, 2946)
named_net("micro.vsel6"):route(4134, 2971)
named_net("micro.vsel7"):route(4144, 2996)
named_net("micro.vsel8"):route(4154, 3021)
named_net("mdrive.10")  :route(4122, 3046, 4122, 2911)
named_net("mdrive.11")  :route(4120, 3071, 4120, 2898)

local function d1(n, x, y, dl, dr)
   local nl = match(n, [[
A=t(a, c, f)
B=t(g, b, c)
C=t(h, c, d)
D=t(i, b, e)
E=d(a, a, j)
F=d(c, c, k)
G=t(d, a, l)
H=t(e, c, m)
I=t(a, a, b)
J=gnd(f)
K=gnd(g)
L=gnd(h)
M=gnd(i)
N=vcc(j)
O=vcc(k)
P=vcc(l)
Q=vcc(m)
]], { d = dl, e = dr })
   latch(n, x+10, y-2, { nr=nl.c })

   move(nl, x, y, [[
G 1 32 ed,
P 0 36,
C 1 24 eh,
L 0 20,

H 1 12 ee,
Q 0 16,
D 1  4 ei,
M 0  0,
]])
   route(nl, x, y, [[
a 10 32,
c 5 27 22 27,
]])
   return nl.b
end

local function d2(n, x, y, o)
   local nl = match(n, [[
D=t(i, b, e)
H=t(e, c, m)
M=gnd(i)
Q=vcc(m)
]], { e = o })
   latch(n, x+10, y-2, { ro=nl.c })

   move(nl, x, y, [[
H 1 12 ee,
Q 0 16,
D 1  4 ei,
M 0  0,
]])
   route(nl, x, y, [[
b 22 2 5 2,
]])
   return nl.b
end

local map = {}

map.i45 = d1(n, 4255, 3060, named_net("mdrive.5"), named_net("mdrive.4"))
map.i23 = d1(n, 4255, 3020, named_net("mdrive.2"), named_net("mdrive.3"))
map.i01 = d1(n, 4255, 2980, named_net("mdrive.1"), named_net("mdrive.0"))
map.i89 = d1(n, 4255, 2940, named_net("mdrive.9"), named_net("mdrive.8"))
map.i67 = d1(n, 4255, 2900, named_net("mdrive.6"), named_net("mdrive.7"))
map.ixx = d2(n, 4255, 2870, bl.i4b)
map.iyy = d2(n, 4255, 2840, bl.i4a)
map.izz = d2(n, 4255, 2810, nodes_rect(4334, 3002, 4336, 3000)[1]:gate())

local n = nodes_rect(4240, 2784, 4350, 2611)
for i=0,3 do
   local nl = match(n, [[
A=t(f, d, b)
B=t(d, c, g)
C=d(d, d, h)
D=t(b, e, a)
E=t(e, i, c)
F=gnd(f)
G=gnd(g)
H=vcc(h)
I=vcc(i)
]], { b = named_net(string.format("mdrive.%d", 12+i)) })
   move(nl, 4300, 2715+25*(3-i), [[
A 1 4 ef,
F 0 0,
D 1 12 eb,
C 9 4 wd,
H 10 8,
B 15 4 eg,
G 14 0,
E 15 13 ne,
I 15 17,
]])
   route(nl, 4300, 2715+25*(3-i), "a -2 16, d 12 8 12 0")
   map[string.format("ii%d", i)] = nl.c
end

local n = nodes_rect(4245, 2683, 4310, 2610)
local nl = match(n, [[
N0=t(n0, n2, n19)
N1=t(n20, n4, n2)
N2=t(ii0, n3, n11)
N3=t(n12, n4, ii0)
N4=t(n13, n1, ii1)
N5=t(ii1, n4, n14)
N6=t(n15, n2, ii2)
N7=t(ii2, n3, n16)
N8=t(n17, n1, ii3)
N9=t(ii3, n2, n18)
N10=d(ii0, ii0, n21)
N11=d(ii1, ii1, n6)
N12=d(n7, ii2, ii2)
N13=d(ii3, ii3, n8)
N14=d(n0, n0, n9)
N15=d(n2, n2, n10)
N16=t(n0, n0, n4)
N17=vcc(n6)
N18=vcc(n7)
N19=vcc(n8)
N20=vcc(n9)
N21=vcc(n10)
N22=gnd(n11)
N23=gnd(n12)
N24=gnd(n13)
N25=gnd(n14)
N26=gnd(n15)
N27=gnd(n16)
N28=gnd(n17)
N29=gnd(n18)
N30=gnd(n19)
N31=gnd(n20)
N32=vcc(n21)
]], map)

move(nl, 0, 0, [[
N2  4345 2790 en11,
N22 4344 2786,
N3  4355 2790 en12,
N23 4354 2786,
N10 4365 2794 wii0,
N32 4366 2798,

N4  4325 2765 en13,
N24 4324 2761,
N5  4355 2765 en14,
N25 4354 2761,
N11 4365 2769 wii1,
N17 4366 2773,

N6  4335 2740 en15,
N26 4334 2736,
N7  4345 2740 en16,
N27 4344 2736,
N12 4365 2744 wii2,
N18 4366 2748,

N8  4325 2715 en17,
N28 4324 2711,
N9  4335 2715 en18,
N29 4334 2711,
N13 4365 2719 wii3,
N19 4366 2723,
]])

local n = nodes_rect(4240, 2685, 4300, 2535)
local nl = match(n, [[
A=t(b, i2, j)
B=t(k, i4, i2)
C=t(l, i1, i3)
D=t(m, i3, c)
E=d(b, b, f)
F=d(i2, i2, g)
G=d(i3, i3, h)
H=d(c, c, i)
I=t(b, b, i4)
J=t(i1, c, c)
K=t(i1, a, e)
L=t(i4, a, d)
M=vcc(f)
N=vcc(g)
O=vcc(h)
P=vcc(i)
Q=gnd(j)
R=gnd(k)
S=gnd(l)
T=gnd(m)
]], { i1 = nl.n1, i2 = nl.n2, i3 = nl.n3, i4 = nl.n4 })

latchi(n, 4390, 2690, { ri=nl.i4 })
latchi(n, 4390, 2660, { ri=nl.i1 })

move(nl, 0, 0, [[
L 4358 2654 wd,
K 4328 2654 we,
]])

route(nl, 0, 0, [[
i2 4339 2700,
i3 4349 2670,
i1 4378 2658 4329 2658,
i4 4378 2688 4359 2688,
a 4106 2661 4354 2661 4324 2661,
]])

local n = nodes_rect(4385, 2535, 4425, 2495)
local nl = match(n, [[
A=t(f, a, i1)
B=t(i1, b, g)
C=t(h, a, i2)
D=t(i2, c, i)
E=d(i1, i1, d)
F=d(e, i2, i2)
G=vcc(d)
H=vcc(e)
I=gnd(f)
J=gnd(g)
K=gnd(h)
L=gnd(i)
]], { i1 = nl.d, i2 = nl.e })

move(nl, 0, 0, [[
E 4440 2640 wi1,
G 4441 2644,
A 4440 2632 wf,
I 4441 2628,
B 4446 2632 eg,
J 4445 2628,

F 4440 2620 wi2,
H 4441 2624,
C 4440 2612 wh,
K 4441 2608,
D 4446 2612 ei,
L 4445 2608,
]])

route(nl, 0, 0, [[
b  4559 2632,
c  4570 2612,
i1 4359 2640,
i2 4329 2620,
a  4434 2612 4434 2632,
]])

named_net("mdrive.12"):route(4062, 2798, 4062, 2835, 4062, 3103)
named_net("mdrive.13"):route(4296, 2773, 4296, 2796, 4060, 2796, 4060, 2845, 4060, 3093)
named_net("mdrive.14"):route(4294, 2748, 4294, 2794, 4058, 2794, 4058, 2855, 4058, 3083)
named_net("mdrive.15"):route(4292, 2723, 4292, 2792, 4056, 2792, 4056, 2865, 4056, 3073, 3460, 3073, 3450, 2865)
named_net("clk_phase_mb_read"):route(4176, 2806)

named_net("mdrive.1"):route(4041, 3008, 4041, 3011)
named_net("mdrive.0"):route(4252, 2988, 4252, 3006, 4043, 3006, 4043, 3021)
named_net("mdrive.2"):route(4252, 3048, 4252, 3033, 4045, 3033, 4045, 3001)
named_net("mdrive.3"):route(4252, 3028, 4252, 3031, 4047, 3031, 4047, 2991)
named_net("mdrive.4"):route(4250, 3068, 4250, 2983, 4041, 2983, 4041, 2981)
named_net("mdrive.5"):route(4248, 3088, 4248, 2981, 4043, 2981, 4043, 2971)
named_net("mdrive.9"):route(4252, 2968, 4252, 2958, 4041, 2958, 4041, 2931)
named_net("mdrive.8"):route(4252, 2948, 4252, 2956, 4043, 2956, 4043, 2941)
named_net("mdrive.6"):route(4252, 2928, 4252, 2933, 4045, 2933, 4045, 2961)
named_net("mdrive.7"):route(4250, 2908, 4250, 2931, 4047, 2931, 4047, 2951)

for i=0,7 do
   microcode.micro_top_latched[i]:set_name("latched_micro."..(16-i))
end

for i=0,8 do
   microcode.micro_bot_latched[i]:set_name("latched_micro."..(8-i))
end

for i=0,31 do
   microcode.nano_top_postsel[i]:set_name("postsel_nano."..(67-i))
end

for i=0,35 do
   microcode.nano_bot_postsel[i]:set_name("postsel_nano."..(35-i))
end

for i=1,118 do
   microcode.drivers_top.vsel[i]:set_name("vsel_t_"..i)
end

for i=1,118 do
   microcode.drivers_bot.vsel[i]:set_name("vsel_b_"..i)
end
